# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/result.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/result.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import medal_pb2 as eolymp_dot_judge_dot_medal__pb2
from eolymp.judge import score_pb2 as eolymp_dot_judge_dot_score__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/judge/result.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/judge/medal.proto\x1a\x18\x65olymp/judge/score.proto\"\xf8\x01\n\x06Result\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x07 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nunofficial\x18\x04 \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x0b \x01(\x08\x12\r\n\x05ghost\x18\t \x01(\x08\x12\"\n\x05medal\x18\x08 \x01(\x0e\x32\x13.eolymp.judge.Medal\x12\x0c\n\x04rank\x18\x05 \x01(\r\x12\x12\n\nrank_lower\x18\x06 \x01(\r\x12\"\n\x05score\x18\n \x01(\x0b\x32\x13.eolymp.judge.ScoreB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_RESULT']._serialized_start=96
  _globals['_RESULT']._serialized_end=344
# @@protoc_insertion_point(module_scope)
