# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/runtime/language.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/runtime/language.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/runtime/language.proto\x12\x0e\x65olymp.runtime\"\xad\x01\n\x08Language\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.eolymp.runtime.Language.Type\x12\x12\n\ndeprecated\x18\x0b \x01(\x08\"F\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bPROGRAMMING\x10\x01\x12\x07\n\x03SQL\x10\x03\x12\x06\n\x02ML\x10\x04\x12\n\n\x05OTHER\x10\xe7\x07\x42\x31Z/github.com/eolymp/go-sdk/eolymp/runtime;runtimeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.runtime.language_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/runtime;runtime'
  _globals['_LANGUAGE']._serialized_start=50
  _globals['_LANGUAGE']._serialized_end=223
  _globals['_LANGUAGE_TYPE']._serialized_start=153
  _globals['_LANGUAGE_TYPE']._serialized_end=223
# @@protoc_insertion_point(module_scope)
