# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/worker/executor_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/worker/executor_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/worker/executor_service.proto\x12\reolymp.worker\"\xad\x01\n\x0f\x45xecuteJobInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12:\n\x06inputs\x18\x0b \x03(\x0b\x32*.eolymp.worker.ExecuteJobInput.InputsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc0\x03\n\x10\x45xecuteJobUpdate\x12\x42\n\x08progress\x18\x01 \x01(\x0b\x32..eolymp.worker.ExecuteJobUpdate.ProgressUpdateH\x00\x12?\n\x07outputs\x18\x02 \x01(\x0b\x32,.eolymp.worker.ExecuteJobUpdate.OutputUpdateH\x00\x12=\n\x04logs\x18\x03 \x01(\x0b\x32-.eolymp.worker.ExecuteJobUpdate.LoggingUpdateH\x00\x1a\x31\n\x0eProgressUpdate\x12\x10\n\x08progress\x18\x01 \x01(\r\x12\r\n\x05total\x18\x02 \x01(\r\x1a\x8a\x01\n\x0cOutputUpdate\x12J\n\x07outputs\x18\x01 \x03(\x0b\x32\x39.eolymp.worker.ExecuteJobUpdate.OutputUpdate.OutputsEntry\x1a.\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x1e\n\rLoggingUpdate\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\x42\x08\n\x06update2d\n\x0f\x45xecutorService\x12Q\n\nExecuteJob\x12\x1e.eolymp.worker.ExecuteJobInput\x1a\x1f.eolymp.worker.ExecuteJobUpdate\"\x00\x30\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/worker;workerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.worker.executor_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/worker;worker'
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._loaded_options = None
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._loaded_options = None
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEJOBINPUT']._serialized_start=56
  _globals['_EXECUTEJOBINPUT']._serialized_end=229
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._serialized_start=184
  _globals['_EXECUTEJOBINPUT_INPUTSENTRY']._serialized_end=229
  _globals['_EXECUTEJOBUPDATE']._serialized_start=232
  _globals['_EXECUTEJOBUPDATE']._serialized_end=680
  _globals['_EXECUTEJOBUPDATE_PROGRESSUPDATE']._serialized_start=448
  _globals['_EXECUTEJOBUPDATE_PROGRESSUPDATE']._serialized_end=497
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE']._serialized_start=500
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE']._serialized_end=638
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._serialized_start=592
  _globals['_EXECUTEJOBUPDATE_OUTPUTUPDATE_OUTPUTSENTRY']._serialized_end=638
  _globals['_EXECUTEJOBUPDATE_LOGGINGUPDATE']._serialized_start=640
  _globals['_EXECUTEJOBUPDATE_LOGGINGUPDATE']._serialized_end=670
  _globals['_EXECUTORSERVICE']._serialized_start=682
  _globals['_EXECUTORSERVICE']._serialized_end=782
# @@protoc_insertion_point(module_scope)
