# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/generation_task.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/executor/generation_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import script_pb2 as eolymp_dot_executor_dot_script__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/executor/generation_task.proto\x12\x0f\x65olymp.executor\x1a\x1c\x65olymp/executor/script.proto\"\xfe\x06\n\x0eGenerationTask\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12?\n\x08metadata\x18\x05 \x03(\x0b\x32-.eolymp.executor.GenerationTask.MetadataEntry\x12\x11\n\trun_count\x18\x10 \x01(\r\x12\x1c\n\x14interactive_followup\x18\x11 \x01(\x08\x12+\n\ninteractor\x18\x19 \x01(\x0b\x32\x17.eolymp.executor.Script\x12*\n\tvalidator\x18\x1a \x01(\x0b\x32\x17.eolymp.executor.Script\x12(\n\x07scripts\x18\x16 \x03(\x0b\x32\x17.eolymp.executor.Script\x12\x31\n\x04runs\x18\n \x03(\x0b\x32#.eolymp.executor.GenerationTask.Run\x1a\x33\n\tGenerator\x12\x13\n\x0bscript_name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\x1a\xa9\x03\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05group\x18\x06 \x01(\r\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x02\x12\x39\n\x03\x65nv\x18\x05 \x03(\x0b\x32,.eolymp.executor.GenerationTask.Run.EnvEntry\x12\x13\n\tinput_url\x18\x0c \x01(\tH\x00\x12\x17\n\rinput_content\x18\x0b \x01(\tH\x00\x12\x44\n\x0finput_generator\x18\r \x01(\x0b\x32).eolymp.executor.GenerationTask.GeneratorH\x00\x12\x14\n\nanswer_url\x18\x16 \x01(\tH\x01\x12\x18\n\x0e\x61nswer_content\x18\x15 \x01(\tH\x01\x12\x45\n\x10\x61nswer_generator\x18\x17 \x01(\x0b\x32).eolymp.executor.GenerationTask.GeneratorH\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05inputB\x08\n\x06\x61nswer\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.generation_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._loaded_options = None
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._serialized_options = b'8\001'
  _globals['_GENERATIONTASK_METADATAENTRY']._loaded_options = None
  _globals['_GENERATIONTASK_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GENERATIONTASK']._serialized_start=89
  _globals['_GENERATIONTASK']._serialized_end=983
  _globals['_GENERATIONTASK_GENERATOR']._serialized_start=455
  _globals['_GENERATIONTASK_GENERATOR']._serialized_end=506
  _globals['_GENERATIONTASK_RUN']._serialized_start=509
  _globals['_GENERATIONTASK_RUN']._serialized_end=934
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._serialized_start=873
  _globals['_GENERATIONTASK_RUN_ENVENTRY']._serialized_end=915
  _globals['_GENERATIONTASK_METADATAENTRY']._serialized_start=936
  _globals['_GENERATIONTASK_METADATAENTRY']._serialized_end=983
# @@protoc_insertion_point(module_scope)
