# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/scoreboard.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/scoreboard.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import medal_pb2 as eolymp_dot_judge_dot_medal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/judge/scoreboard.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/judge/medal.proto\"\x82\n\n\nScoreboard\x12,\n\x05modes\x18\n \x03(\x0e\x32\x1d.eolymp.judge.Scoreboard.Mode\x12.\n\x06rounds\x18\x0c \x03(\x0b\x32\x1e.eolymp.judge.Scoreboard.Round\x12\x30\n\x07\x63olumns\x18\x0b \x03(\x0b\x32\x1f.eolymp.judge.Scoreboard.Column\x1a\"\n\x05Round\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x1a\xbe\x02\n\x06\x43olumn\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.eolymp.judge.Scoreboard.Column.Type\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0f\n\x07\x63hoices\x18\n \x03(\t\x12\x10\n\x08sortable\x18\x14 \x01(\x08\x12\x12\n\nfilterable\x18\x15 \x01(\x08\"\xad\x01\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0f\n\x0bROUND_SCORE\x10\x02\x12\x11\n\rPROBLEM_SCORE\x10\x03\x12\n\n\x06STRING\x10\n\x12\n\n\x06NUMBER\x10\x0b\x12\n\n\x06\x43HOICE\x10\x0c\x12\x08\n\x04\x44\x41TE\x10\r\x12\t\n\x05\x45MAIL\x10\x0e\x12\x0c\n\x08\x43HECKBOX\x10\x0f\x12\x0b\n\x07\x43OUNTRY\x10\x10\x12\n\n\x06REGION\x10\x11\x12\x0f\n\x0bINSTITUTION\x10\x12\x1a\xd1\x05\n\x03Row\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x0c\n\x04rank\x18\x0b \x01(\r\x12\x13\n\x0brank_length\x18\x0c \x01(\r\x12\r\n\x05score\x18\x14 \x01(\x02\x12\x0f\n\x07penalty\x18\x15 \x01(\x02\x12\x13\n\x0btie_breaker\x18\x16 \x01(\r\x12\x12\n\nunofficial\x18\x1e \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x1f \x01(\x08\x12\"\n\x05medal\x18  \x01(\x0e\x32\x13.eolymp.judge.Medal\x12\x32\n\x06values\x18\x32 \x03(\x0b\x32\".eolymp.judge.Scoreboard.Row.Value\x1a\xcb\x01\n\x05Value\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\x12>\n\x0bround_score\x18\x0b \x01(\x0b\x32\'.eolymp.judge.Scoreboard.Row.RoundScoreH\x00\x12\x42\n\rproblem_score\x18\x0c \x01(\x0b\x32).eolymp.judge.Scoreboard.Row.ProblemScoreH\x00\x12\x10\n\x06string\x18\r \x01(\tH\x00\x12\x10\n\x06number\x18\x0e \x01(\tH\x00\x42\x07\n\x05value\x1a\x8f\x01\n\nRoundScore\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x0f\n\x07penalty\x18\x02 \x01(\x02\x12\x13\n\x0btie_breaker\x18\x03 \x01(\r\x12\x12\n\nunofficial\x18\n \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x0b \x01(\x08\x12\"\n\x05medal\x18  \x01(\x0e\x32\x13.eolymp.judge.Medal\x1a\x62\n\x0cProblemScore\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x0f\n\x07penalty\x18\x02 \x01(\x02\x12\x10\n\x08\x61ttempts\x18\x03 \x01(\r\x12\x12\n\npercentage\x18\x04 \x01(\x02\x12\x0c\n\x04time\x18\x05 \x01(\r\"+\n\x04Mode\x12\n\n\x06RESULT\x10\x00\x12\n\n\x06\x46ROZEN\x10\x01\x12\x0b\n\x07UPSOLVE\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.scoreboard_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_SCOREBOARD']._serialized_start=74
  _globals['_SCOREBOARD']._serialized_end=1356
  _globals['_SCOREBOARD_ROUND']._serialized_start=232
  _globals['_SCOREBOARD_ROUND']._serialized_end=266
  _globals['_SCOREBOARD_COLUMN']._serialized_start=269
  _globals['_SCOREBOARD_COLUMN']._serialized_end=587
  _globals['_SCOREBOARD_COLUMN_TYPE']._serialized_start=414
  _globals['_SCOREBOARD_COLUMN_TYPE']._serialized_end=587
  _globals['_SCOREBOARD_ROW']._serialized_start=590
  _globals['_SCOREBOARD_ROW']._serialized_end=1311
  _globals['_SCOREBOARD_ROW_VALUE']._serialized_start=862
  _globals['_SCOREBOARD_ROW_VALUE']._serialized_end=1065
  _globals['_SCOREBOARD_ROW_ROUNDSCORE']._serialized_start=1068
  _globals['_SCOREBOARD_ROW_ROUNDSCORE']._serialized_end=1211
  _globals['_SCOREBOARD_ROW_PROBLEMSCORE']._serialized_start=1213
  _globals['_SCOREBOARD_ROW_PROBLEMSCORE']._serialized_end=1311
  _globals['_SCOREBOARD_MODE']._serialized_start=1313
  _globals['_SCOREBOARD_MODE']._serialized_end=1356
# @@protoc_insertion_point(module_scope)
