# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/violation_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/violation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import violation_pb2 as eolymp_dot_judge_dot_violation__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/judge/violation_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/judge/violation.proto\x1a!eolymp/wellknown/expression.proto\"W\n\x14\x43reateViolationInput\x12*\n\tviolation\x18\x01 \x01(\x0b\x32\x17.eolymp.judge.Violation\x12\x13\n\x0b\x64ont_notify\x18\x02 \x01(\x08\"-\n\x15\x43reateViolationOutput\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\"\x8c\x01\n\x14UpdateViolationInput\x12\x32\n\x05patch\x18\x03 \x03(\x0e\x32#.eolymp.judge.Violation.Patch.Field\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\x12*\n\tviolation\x18\x02 \x01(\x0b\x32\x17.eolymp.judge.Violation\"\x17\n\x15UpdateViolationOutput\",\n\x14\x44\x65leteViolationInput\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteViolationOutput\".\n\x16\x44\x65scribeViolationInput\x12\x14\n\x0cviolation_id\x18\x01 \x01(\t\"E\n\x17\x44\x65scribeViolationOutput\x12*\n\tviolation\x18\x01 \x01(\x0b\x32\x17.eolymp.judge.Violation\"\xca\x04\n\x13ListViolationsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.judge.ListViolationsInput.Filter\x1a\xd9\x03\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04type\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x33\n\x07summary\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x33\n\tautomatic\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x36\n\x0eparticipant_id\x18\x06 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x35\n\rsubmission_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncreated_by\x18\x07 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x0c\x63onfirmed_by\x18\t \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"M\n\x14ListViolationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.judge.Violation2\xcc\x06\n\x10ViolationService\x12\x99\x01\n\x0f\x43reateViolation\x12\".eolymp.judge.CreateViolationInput\x1a#.eolymp.judge.CreateViolationOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\r\"\x0b/violations\x12\xa8\x01\n\x0fUpdateViolation\x12\".eolymp.judge.UpdateViolationInput\x1a#.eolymp.judge.UpdateViolationOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1c\"\x1a/violations/{violation_id}\x12\xa8\x01\n\x0f\x44\x65leteViolation\x12\".eolymp.judge.DeleteViolationInput\x1a#.eolymp.judge.DeleteViolationOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1c*\x1a/violations/{violation_id}\x12\xad\x01\n\x11\x44\x65scribeViolation\x12$.eolymp.judge.DescribeViolationInput\x1a%.eolymp.judge.DescribeViolationOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x1c\x12\x1a/violations/{violation_id}\x12\x95\x01\n\x0eListViolations\x12!.eolymp.judge.ListViolationsInput\x1a\".eolymp.judge.ListViolationsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\r\x12\x0b/violationsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.violation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_VIOLATIONSERVICE'].methods_by_name['CreateViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['CreateViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\r\"\013/violations'
  _globals['_VIOLATIONSERVICE'].methods_by_name['UpdateViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['UpdateViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\034\"\032/violations/{violation_id}'
  _globals['_VIOLATIONSERVICE'].methods_by_name['DeleteViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['DeleteViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\034*\032/violations/{violation_id}'
  _globals['_VIOLATIONSERVICE'].methods_by_name['DescribeViolation']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['DescribeViolation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\034\022\032/violations/{violation_id}'
  _globals['_VIOLATIONSERVICE'].methods_by_name['ListViolations']._loaded_options = None
  _globals['_VIOLATIONSERVICE'].methods_by_name['ListViolations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\r\022\013/violations'
  _globals['_CREATEVIOLATIONINPUT']._serialized_start=218
  _globals['_CREATEVIOLATIONINPUT']._serialized_end=305
  _globals['_CREATEVIOLATIONOUTPUT']._serialized_start=307
  _globals['_CREATEVIOLATIONOUTPUT']._serialized_end=352
  _globals['_UPDATEVIOLATIONINPUT']._serialized_start=355
  _globals['_UPDATEVIOLATIONINPUT']._serialized_end=495
  _globals['_UPDATEVIOLATIONOUTPUT']._serialized_start=497
  _globals['_UPDATEVIOLATIONOUTPUT']._serialized_end=520
  _globals['_DELETEVIOLATIONINPUT']._serialized_start=522
  _globals['_DELETEVIOLATIONINPUT']._serialized_end=566
  _globals['_DELETEVIOLATIONOUTPUT']._serialized_start=568
  _globals['_DELETEVIOLATIONOUTPUT']._serialized_end=591
  _globals['_DESCRIBEVIOLATIONINPUT']._serialized_start=593
  _globals['_DESCRIBEVIOLATIONINPUT']._serialized_end=639
  _globals['_DESCRIBEVIOLATIONOUTPUT']._serialized_start=641
  _globals['_DESCRIBEVIOLATIONOUTPUT']._serialized_end=710
  _globals['_LISTVIOLATIONSINPUT']._serialized_start=713
  _globals['_LISTVIOLATIONSINPUT']._serialized_end=1299
  _globals['_LISTVIOLATIONSINPUT_FILTER']._serialized_start=826
  _globals['_LISTVIOLATIONSINPUT_FILTER']._serialized_end=1299
  _globals['_LISTVIOLATIONSOUTPUT']._serialized_start=1301
  _globals['_LISTVIOLATIONSOUTPUT']._serialized_end=1378
  _globals['_VIOLATIONSERVICE']._serialized_start=1381
  _globals['_VIOLATIONSERVICE']._serialized_end=2225
# @@protoc_insertion_point(module_scope)
