# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/helpdesk/ticket_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/helpdesk/ticket_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.helpdesk import ticket_pb2 as eolymp_dot_helpdesk_dot_ticket__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/helpdesk/ticket_service.proto\x12\x0f\x65olymp.helpdesk\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/helpdesk/ticket.proto\x1a!eolymp/wellknown/expression.proto\"M\n\x11\x43reateTicketInput\x12\'\n\x06ticket\x18\x01 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\x12\x0f\n\x07\x63\x61ptcha\x18\x02 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"O\n\x11UpdateTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\'\n\x06ticket\x18\x02 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\"\x14\n\x12UpdateTicketOutput\"&\n\x11\x44\x65leteTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"8\n\x13\x44\x65scribeTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\"?\n\x14\x44\x65scribeTicketOutput\x12\'\n\x06ticket\x18\x01 \x01(\x0b\x32\x17.eolymp.helpdesk.Ticket\"\xb2\x04\n\x10ListTicketsInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.helpdesk.ListTicketsInput.Filter\x1a\xb4\x03\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\nuser_email\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04type\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x39\n\ncreated_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x39\n\nupdated_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06locale\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"J\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.helpdesk.Ticket\"8\n\x12\x41pproveTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x15\n\x13\x41pproveTicketOutput\"7\n\x11RejectTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x14\n\x12RejectTicketOutput\"6\n\x10\x43loseTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\x13\n\x11\x43loseTicketOutput\"V\n\x0f\x41\x64\x64\x43ommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x30\n\x07\x63omment\x18\x02 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"&\n\x10\x41\x64\x64\x43ommentOutput\x12\x12\n\ncomment_id\x18\x01 \x01(\t\"m\n\x12UpdateCommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x12\n\ncomment_id\x18\x02 \x01(\t\x12\x30\n\x07\x63omment\x18\x03 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"\x15\n\x13UpdateCommentOutput\";\n\x12\x44\x65leteCommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x12\n\ncomment_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteCommentOutput\"T\n\x11ListCommentsInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"S\n\x12ListCommentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"M\n\x14\x44\x65scribeCommentInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x12\n\ncomment_id\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\"I\n\x15\x44\x65scribeCommentOutput\x12\x30\n\x07\x63omment\x18\x01 \x01(\x0b\x32\x1f.eolymp.helpdesk.Ticket.Comment\"A\n\x15UploadAttachmentInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"0\n\x16UploadAttachmentOutput\x12\x16\n\x0e\x61ttachment_url\x18\x01 \x01(\t2\xe3\x13\n\rTicketService\x12\x9e\x01\n\x0c\x43reateTicket\x12\".eolymp.helpdesk.CreateTicketInput\x1a#.eolymp.helpdesk.CreateTicketOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x13\"\x11/helpdesk/tickets\x12\xaa\x01\n\x0cUpdateTicket\x12\".eolymp.helpdesk.UpdateTicketInput\x1a#.eolymp.helpdesk.UpdateTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/helpdesk/tickets/{ticket_id}\x12\xaa\x01\n\x0c\x44\x65leteTicket\x12\".eolymp.helpdesk.DeleteTicketInput\x1a#.eolymp.helpdesk.DeleteTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f*\x1d/helpdesk/tickets/{ticket_id}\x12\xaf\x01\n\x0e\x44\x65scribeTicket\x12$.eolymp.helpdesk.DescribeTicketInput\x1a%.eolymp.helpdesk.DescribeTicketOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/helpdesk/tickets/{ticket_id}\x12\x9a\x01\n\x0bListTickets\x12!.eolymp.helpdesk.ListTicketsInput\x1a\".eolymp.helpdesk.ListTicketsOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x13\x12\x11/helpdesk/tickets\x12\xb5\x01\n\rApproveTicket\x12#.eolymp.helpdesk.ApproveTicketInput\x1a$.eolymp.helpdesk.ApproveTicketOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\'\"%/helpdesk/tickets/{ticket_id}/approve\x12\xb1\x01\n\x0cRejectTicket\x12\".eolymp.helpdesk.RejectTicketInput\x1a#.eolymp.helpdesk.RejectTicketOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02&\"$/helpdesk/tickets/{ticket_id}/reject\x12\xad\x01\n\x0b\x43loseTicket\x12!.eolymp.helpdesk.CloseTicketInput\x1a\".eolymp.helpdesk.CloseTicketOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02%\"#/helpdesk/tickets/{ticket_id}/close\x12\xad\x01\n\nAddComment\x12 .eolymp.helpdesk.AddCommentInput\x1a!.eolymp.helpdesk.AddCommentOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02(\"&/helpdesk/tickets/{ticket_id}/comments\x12\xc3\x01\n\rUpdateComment\x12#.eolymp.helpdesk.UpdateCommentInput\x1a$.eolymp.helpdesk.UpdateCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x1a\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xc3\x01\n\rDeleteComment\x12#.eolymp.helpdesk.DeleteCommentInput\x1a$.eolymp.helpdesk.DeleteCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xb2\x01\n\x0cListComments\x12\".eolymp.helpdesk.ListCommentsInput\x1a#.eolymp.helpdesk.ListCommentsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02(\x12&/helpdesk/tickets/{ticket_id}/comments\x12\xc9\x01\n\x0f\x44\x65scribeComment\x12%.eolymp.helpdesk.DescribeCommentInput\x1a&.eolymp.helpdesk.DescribeCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x12\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xae\x01\n\x10UploadAttachment\x12&.eolymp.helpdesk.UploadAttachmentInput\x1a\'.eolymp.helpdesk.UploadAttachmentOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x17\"\x15/helpdesk/attachmentsB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.ticket_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['CreateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\023\"\021/helpdesk/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037\032\035/helpdesk/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037*\035/helpdesk/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\037\022\035/helpdesk/tickets/{ticket_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListTickets']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\023\022\021/helpdesk/tickets'
  _globals['_TICKETSERVICE'].methods_by_name['ApproveTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ApproveTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\'\"%/helpdesk/tickets/{ticket_id}/approve'
  _globals['_TICKETSERVICE'].methods_by_name['RejectTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['RejectTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002&\"$/helpdesk/tickets/{ticket_id}/reject'
  _globals['_TICKETSERVICE'].methods_by_name['CloseTicket']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['CloseTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002%\"#/helpdesk/tickets/{ticket_id}/close'
  _globals['_TICKETSERVICE'].methods_by_name['AddComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['AddComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002(\"&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_TICKETSERVICE'].methods_by_name['UpdateComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UpdateComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0323/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_TICKETSERVICE'].methods_by_name['DeleteComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DeleteComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_TICKETSERVICE'].methods_by_name['ListComments']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['ListComments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002(\022&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_TICKETSERVICE'].methods_by_name['DescribeComment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['DescribeComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0223/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_TICKETSERVICE'].methods_by_name['UploadAttachment']._loaded_options = None
  _globals['_TICKETSERVICE'].methods_by_name['UploadAttachment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\027\"\025/helpdesk/attachments'
  _globals['_CREATETICKETINPUT']._serialized_start=221
  _globals['_CREATETICKETINPUT']._serialized_end=298
  _globals['_CREATETICKETOUTPUT']._serialized_start=300
  _globals['_CREATETICKETOUTPUT']._serialized_end=339
  _globals['_UPDATETICKETINPUT']._serialized_start=341
  _globals['_UPDATETICKETINPUT']._serialized_end=420
  _globals['_UPDATETICKETOUTPUT']._serialized_start=422
  _globals['_UPDATETICKETOUTPUT']._serialized_end=442
  _globals['_DELETETICKETINPUT']._serialized_start=444
  _globals['_DELETETICKETINPUT']._serialized_end=482
  _globals['_DELETETICKETOUTPUT']._serialized_start=484
  _globals['_DELETETICKETOUTPUT']._serialized_end=504
  _globals['_DESCRIBETICKETINPUT']._serialized_start=506
  _globals['_DESCRIBETICKETINPUT']._serialized_end=562
  _globals['_DESCRIBETICKETOUTPUT']._serialized_start=564
  _globals['_DESCRIBETICKETOUTPUT']._serialized_end=627
  _globals['_LISTTICKETSINPUT']._serialized_start=630
  _globals['_LISTTICKETSINPUT']._serialized_end=1192
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_start=756
  _globals['_LISTTICKETSINPUT_FILTER']._serialized_end=1192
  _globals['_LISTTICKETSOUTPUT']._serialized_start=1194
  _globals['_LISTTICKETSOUTPUT']._serialized_end=1268
  _globals['_APPROVETICKETINPUT']._serialized_start=1270
  _globals['_APPROVETICKETINPUT']._serialized_end=1326
  _globals['_APPROVETICKETOUTPUT']._serialized_start=1328
  _globals['_APPROVETICKETOUTPUT']._serialized_end=1349
  _globals['_REJECTTICKETINPUT']._serialized_start=1351
  _globals['_REJECTTICKETINPUT']._serialized_end=1406
  _globals['_REJECTTICKETOUTPUT']._serialized_start=1408
  _globals['_REJECTTICKETOUTPUT']._serialized_end=1428
  _globals['_CLOSETICKETINPUT']._serialized_start=1430
  _globals['_CLOSETICKETINPUT']._serialized_end=1484
  _globals['_CLOSETICKETOUTPUT']._serialized_start=1486
  _globals['_CLOSETICKETOUTPUT']._serialized_end=1505
  _globals['_ADDCOMMENTINPUT']._serialized_start=1507
  _globals['_ADDCOMMENTINPUT']._serialized_end=1593
  _globals['_ADDCOMMENTOUTPUT']._serialized_start=1595
  _globals['_ADDCOMMENTOUTPUT']._serialized_end=1633
  _globals['_UPDATECOMMENTINPUT']._serialized_start=1635
  _globals['_UPDATECOMMENTINPUT']._serialized_end=1744
  _globals['_UPDATECOMMENTOUTPUT']._serialized_start=1746
  _globals['_UPDATECOMMENTOUTPUT']._serialized_end=1767
  _globals['_DELETECOMMENTINPUT']._serialized_start=1769
  _globals['_DELETECOMMENTINPUT']._serialized_end=1828
  _globals['_DELETECOMMENTOUTPUT']._serialized_start=1830
  _globals['_DELETECOMMENTOUTPUT']._serialized_end=1851
  _globals['_LISTCOMMENTSINPUT']._serialized_start=1853
  _globals['_LISTCOMMENTSINPUT']._serialized_end=1937
  _globals['_LISTCOMMENTSOUTPUT']._serialized_start=1939
  _globals['_LISTCOMMENTSOUTPUT']._serialized_end=2022
  _globals['_DESCRIBECOMMENTINPUT']._serialized_start=2024
  _globals['_DESCRIBECOMMENTINPUT']._serialized_end=2101
  _globals['_DESCRIBECOMMENTOUTPUT']._serialized_start=2103
  _globals['_DESCRIBECOMMENTOUTPUT']._serialized_end=2176
  _globals['_UPLOADATTACHMENTINPUT']._serialized_start=2178
  _globals['_UPLOADATTACHMENTINPUT']._serialized_end=2243
  _globals['_UPLOADATTACHMENTOUTPUT']._serialized_start=2245
  _globals['_UPLOADATTACHMENTOUTPUT']._serialized_end=2293
  _globals['_TICKETSERVICE']._serialized_start=2296
  _globals['_TICKETSERVICE']._serialized_end=4827
# @@protoc_insertion_point(module_scope)
