# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/shopping_cart.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/shopping_cart.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import address_pb2 as eolymp_dot_commerce_dot_address__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/commerce/shopping_cart.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/commerce/address.proto\"\x90\x04\n\x0cShoppingCart\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\x05items\x18\n \x03(\x0b\x32\".eolymp.commerce.ShoppingCart.Item\x12\x31\n\x0f\x62illing_address\x18( \x01(\x0b\x32\x18.eolymp.commerce.Address\x12\x32\n\x10shipping_address\x18) \x01(\x0b\x32\x18.eolymp.commerce.Address\x12 \n\x18\x62illing_same_as_shipping\x18* \x01(\x08\x12\x10\n\x08\x63urrency\x18\x14 \x01(\t\x12\x14\n\x0ctotal_amount\x18\x15 \x01(\r\x12\x17\n\x0fshipping_amount\x18\x16 \x01(\r\x12\x17\n\x0f\x64iscount_amount\x18\x17 \x01(\r\x12\x12\n\ntax_amount\x18\x18 \x01(\r\x12\x10\n\x08tax_rate\x18\x19 \x01(\r\x12\x10\n\x08tax_note\x18\x1a \x01(\t\x12\x13\n\x0bgrand_total\x18\x1e \x01(\r\x1a\x90\x01\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x12\n\nvariant_id\x18\x03 \x01(\t\x12\x10\n\x08quantity\x18\n \x01(\r\x12\x13\n\x0bunit_amount\x18\x15 \x01(\r\x12\x14\n\x0ctotal_amount\x18\x16 \x01(\r\x12\x17\n\x0f\x64iscount_amount\x18\x17 \x01(\rB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.shopping_cart_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_SHOPPINGCART']._serialized_start=88
  _globals['_SHOPPINGCART']._serialized_end=616
  _globals['_SHOPPINGCART_ITEM']._serialized_start=472
  _globals['_SHOPPINGCART_ITEM']._serialized_end=616
# @@protoc_insertion_point(module_scope)
