# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/post_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/post_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import post_pb2 as eolymp_dot_discussion_dot_post__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/discussion/post_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/discussion/post.proto\x1a\x18\x65olymp/ecm/content.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x88\x01\n\x10PostChangedEvent\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.discussion.Post\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"s\n\x12PostPublishedEvent\x12\x11\n\tpublished\x18\x01 \x01(\x08\x12%\n\x04post\x18\x02 \x01(\x0b\x32\x17.eolymp.discussion.Post\x12#\n\x06reason\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\xbc\x01\n\x1bPostTranslationChangedEvent\x12\x0f\n\x07post_id\x18\n \x01(\t\x12\x33\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\x12\x32\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"c\n\x11\x44\x65scribePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18< \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\";\n\x12\x44\x65scribePostOutput\x12%\n\x04post\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\"\xbc\x08\n\x0eListPostsInput\x12\r\n\x05\x61\x66ter\x18\n \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\x0c \x01(\x05\x12\x34\n\x04sort\x18\x32 \x01(\x0e\x32&.eolymp.discussion.ListPostsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.discussion.ListPostsInput.Filter\x12\x0e\n\x06locale\x18< \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\x1a\xb3\x05\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tsource_id\x18\r \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07type_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x39\n\ncreated_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12;\n\x0cpublished_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12/\n\x05\x64raft\x18\x0e \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06public\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08\x66\x65\x61tured\x18\x0f \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nmoderation\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06locale\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12/\n\x05label\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"k\n\x04Sort\x12\x10\n\x0cUNKNOWN_SORT\x10\x00\x12\x10\n\x0cPUBLISHED_AT\x10\x01\x12\x0e\n\nCREATED_AT\x10\x02\x12\x0e\n\nVOTE_COUNT\x10\x03\x12\x0f\n\x0bREPLY_COUNT\x10\x04\x12\x0e\n\nPOPULARITY\x10\x05\"b\n\x0fListPostsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.discussion.Post\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"8\n\x0f\x43reatePostInput\x12%\n\x04post\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\"#\n\x10\x43reatePostOutput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"\xfb\x01\n\x0fUpdatePostInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.discussion.UpdatePostInput.Patch\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12%\n\x04post\x18\x03 \x01(\x0b\x32\x17.eolymp.discussion.Post\"w\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\n\n\x06LABELS\x10\x02\x12\x0b\n\x07TYPE_ID\x10\x03\x12\n\n\x06LOCALE\x10\x04\x12\t\n\x05\x44RAFT\x10\x05\x12\x0c\n\x08\x46\x45\x41TURED\x10\x07\x12\n\n\x06PINNED\x10\x08\x12\x0e\n\nMODERATION\x10\x06\"\x12\n\x10UpdatePostOutput\"#\n\x10PublishPostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"\x13\n\x11PublishPostOutput\"J\n\x12UnpublishPostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x15\n\x13UnpublishPostOutput\"\xd3\x01\n\x11ModeratePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12=\n\x07outcome\x18\x02 \x01(\x0e\x32,.eolymp.discussion.ModeratePostInput.Outcome\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"I\n\x07Outcome\x12\x13\n\x0fUNKNOWN_OUTCOME\x10\x00\x12\x0c\n\x08\x41PPROVED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\r\n\tIN_REVIEW\x10\x03\"\x14\n\x12ModeratePostOutput\"\"\n\x0f\x44\x65letePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"7\n\x10\x44\x65letePostOutput\x12#\n\x06reason\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\".\n\rVotePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"$\n\x0eVotePostOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\"x\n\x12TranslatePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\"%\n\x13TranslatePostOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"v\n\x1c\x44\x65scribePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\"Y\n\x1d\x44\x65scribePostTranslationOutput\x12\x38\n\x0btranslation\x18\x01 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"\xb6\x02\n\x19ListPostTranslationsInput\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x44\n\x07\x66ilters\x18( \x01(\x0b\x32\x33.eolymp.discussion.ListPostTranslationsInput.Filter\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"_\n\x1aListPostTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.eolymp.discussion.Post.Translation\"g\n\x1a\x43reatePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x38\n\x0btranslation\x18\x02 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"5\n\x1b\x43reatePostTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xfa\x01\n\x1aUpdatePostTranslationInput\x12\x42\n\x05patch\x18\x01 \x03(\x0e\x32\x33.eolymp.discussion.UpdatePostTranslationInput.Patch\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12\x38\n\x0btranslation\x18\x04 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"5\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\n\n\x06LABELS\x10\x02\x12\n\n\x06LOCALE\x10\x04\"\x1d\n\x1bUpdatePostTranslationOutput\"E\n\x1a\x44\x65letePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65letePostTranslationOutput2\xaf\x15\n\x0bPostService\x12\xa1\x01\n\x0c\x44\x65scribePost\x12$.eolymp.discussion.DescribePostInput\x1a%.eolymp.discussion.DescribePostOutput\"D\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x18\x8a\xe3\n\x14\x64iscussion:post:read\x82\xd3\xe4\x93\x02\x12\x12\x10/posts/{post_id}\x12\x8d\x01\n\tListPosts\x12!.eolymp.discussion.ListPostsInput\x1a\".eolymp.discussion.ListPostsOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x18\x8a\xe3\n\x14\x64iscussion:post:read\x82\xd3\xe4\x93\x02\x08\x12\x06/posts\x12\x91\x01\n\nCreatePost\x12\".eolymp.discussion.CreatePostInput\x1a#.eolymp.discussion.CreatePostOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x08\"\x06/posts\x12\x9b\x01\n\nUpdatePost\x12\".eolymp.discussion.UpdatePostInput\x1a#.eolymp.discussion.UpdatePostOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x12\x1a\x10/posts/{post_id}\x12\xa6\x01\n\x0bPublishPost\x12#.eolymp.discussion.PublishPostInput\x1a$.eolymp.discussion.PublishPostOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x1a\"\x18/posts/{post_id}/publish\x12\xac\x01\n\rUnpublishPost\x12%.eolymp.discussion.UnpublishPostInput\x1a&.eolymp.discussion.UnpublishPostOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x1a*\x18/posts/{post_id}/publish\x12\xaa\x01\n\x0cModeratePost\x12$.eolymp.discussion.ModeratePostInput\x1a%.eolymp.discussion.ModeratePostOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x1b\"\x19/posts/{post_id}/moderate\x12\x9b\x01\n\nDeletePost\x12\".eolymp.discussion.DeletePostInput\x1a#.eolymp.discussion.DeletePostOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\x82\xd3\xe4\x93\x02\x12*\x10/posts/{post_id}\x12\x9d\x01\n\x08VotePost\x12 .eolymp.discussion.VotePostInput\x1a!.eolymp.discussion.VotePostOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x17\"\x15/posts/{post_id}/vote\x12\xb1\x01\n\rTranslatePost\x12%.eolymp.discussion.TranslatePostInput\x1a&.eolymp.discussion.TranslatePostOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1c\"\x1a/posts/{post_id}/translate\x12\xe4\x01\n\x17\x44\x65scribePostTranslation\x12/.eolymp.discussion.DescribePostTranslationInput\x1a\x30.eolymp.discussion.DescribePostTranslationOutput\"f\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x30\x12./posts/{post_id}/translations/{translation_id}\x12\xc9\x01\n\x14ListPostTranslations\x12,.eolymp.discussion.ListPostTranslationsInput\x1a-.eolymp.discussion.ListPostTranslationsOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/posts/{post_id}/translations\x12\xcd\x01\n\x15\x43reatePostTranslation\x12-.eolymp.discussion.CreatePostTranslationInput\x1a..eolymp.discussion.CreatePostTranslationOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/posts/{post_id}/translations\x12\xde\x01\n\x15UpdatePostTranslation\x12-.eolymp.discussion.UpdatePostTranslationInput\x1a..eolymp.discussion.UpdatePostTranslationOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x30\x1a./posts/{post_id}/translations/{translation_id}\x12\xde\x01\n\x15\x44\x65letePostTranslation\x12-.eolymp.discussion.DeletePostTranslationInput\x1a..eolymp.discussion.DeletePostTranslationOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\x82\xd3\xe4\x93\x02\x30*./posts/{post_id}/translations/{translation_id}B7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.post_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_POSTSERVICE'].methods_by_name['DescribePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DescribePost']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\030\212\343\n\024discussion:post:read\202\323\344\223\002\022\022\020/posts/{post_id}'
  _globals['_POSTSERVICE'].methods_by_name['ListPosts']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['ListPosts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\030\212\343\n\024discussion:post:read\202\323\344\223\002\010\022\006/posts'
  _globals['_POSTSERVICE'].methods_by_name['CreatePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['CreatePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\010\"\006/posts'
  _globals['_POSTSERVICE'].methods_by_name['UpdatePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['UpdatePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\022\032\020/posts/{post_id}'
  _globals['_POSTSERVICE'].methods_by_name['PublishPost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['PublishPost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\032\"\030/posts/{post_id}/publish'
  _globals['_POSTSERVICE'].methods_by_name['UnpublishPost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['UnpublishPost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\032*\030/posts/{post_id}/publish'
  _globals['_POSTSERVICE'].methods_by_name['ModeratePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['ModeratePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\033\"\031/posts/{post_id}/moderate'
  _globals['_POSTSERVICE'].methods_by_name['DeletePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DeletePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025discussion:post:write\202\323\344\223\002\022*\020/posts/{post_id}'
  _globals['_POSTSERVICE'].methods_by_name['VotePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['VotePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\027\"\025/posts/{post_id}/vote'
  _globals['_POSTSERVICE'].methods_by_name['TranslatePost']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['TranslatePost']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\034\"\032/posts/{post_id}/translate'
  _globals['_POSTSERVICE'].methods_by_name['DescribePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DescribePostTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\0020\022./posts/{post_id}/translations/{translation_id}'
  _globals['_POSTSERVICE'].methods_by_name['ListPostTranslations']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['ListPostTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\034\212\343\n\030typewriter:fragment:read\202\323\344\223\002\037\022\035/posts/{post_id}/translations'
  _globals['_POSTSERVICE'].methods_by_name['CreatePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['CreatePostTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\002\037\"\035/posts/{post_id}/translations'
  _globals['_POSTSERVICE'].methods_by_name['UpdatePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['UpdatePostTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\0020\032./posts/{post_id}/translations/{translation_id}'
  _globals['_POSTSERVICE'].methods_by_name['DeletePostTranslation']._loaded_options = None
  _globals['_POSTSERVICE'].methods_by_name['DeletePostTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031typewriter:fragment:write\202\323\344\223\0020*./posts/{post_id}/translations/{translation_id}'
  _globals['_POSTCHANGEDEVENT']._serialized_start=284
  _globals['_POSTCHANGEDEVENT']._serialized_end=420
  _globals['_POSTPUBLISHEDEVENT']._serialized_start=422
  _globals['_POSTPUBLISHEDEVENT']._serialized_end=537
  _globals['_POSTTRANSLATIONCHANGEDEVENT']._serialized_start=540
  _globals['_POSTTRANSLATIONCHANGEDEVENT']._serialized_end=728
  _globals['_DESCRIBEPOSTINPUT']._serialized_start=730
  _globals['_DESCRIBEPOSTINPUT']._serialized_end=829
  _globals['_DESCRIBEPOSTOUTPUT']._serialized_start=831
  _globals['_DESCRIBEPOSTOUTPUT']._serialized_end=890
  _globals['_LISTPOSTSINPUT']._serialized_start=893
  _globals['_LISTPOSTSINPUT']._serialized_end=1977
  _globals['_LISTPOSTSINPUT_FILTER']._serialized_start=1177
  _globals['_LISTPOSTSINPUT_FILTER']._serialized_end=1868
  _globals['_LISTPOSTSINPUT_SORT']._serialized_start=1870
  _globals['_LISTPOSTSINPUT_SORT']._serialized_end=1977
  _globals['_LISTPOSTSOUTPUT']._serialized_start=1979
  _globals['_LISTPOSTSOUTPUT']._serialized_end=2077
  _globals['_CREATEPOSTINPUT']._serialized_start=2079
  _globals['_CREATEPOSTINPUT']._serialized_end=2135
  _globals['_CREATEPOSTOUTPUT']._serialized_start=2137
  _globals['_CREATEPOSTOUTPUT']._serialized_end=2172
  _globals['_UPDATEPOSTINPUT']._serialized_start=2175
  _globals['_UPDATEPOSTINPUT']._serialized_end=2426
  _globals['_UPDATEPOSTINPUT_PATCH']._serialized_start=2307
  _globals['_UPDATEPOSTINPUT_PATCH']._serialized_end=2426
  _globals['_UPDATEPOSTOUTPUT']._serialized_start=2428
  _globals['_UPDATEPOSTOUTPUT']._serialized_end=2446
  _globals['_PUBLISHPOSTINPUT']._serialized_start=2448
  _globals['_PUBLISHPOSTINPUT']._serialized_end=2483
  _globals['_PUBLISHPOSTOUTPUT']._serialized_start=2485
  _globals['_PUBLISHPOSTOUTPUT']._serialized_end=2504
  _globals['_UNPUBLISHPOSTINPUT']._serialized_start=2506
  _globals['_UNPUBLISHPOSTINPUT']._serialized_end=2580
  _globals['_UNPUBLISHPOSTOUTPUT']._serialized_start=2582
  _globals['_UNPUBLISHPOSTOUTPUT']._serialized_end=2603
  _globals['_MODERATEPOSTINPUT']._serialized_start=2606
  _globals['_MODERATEPOSTINPUT']._serialized_end=2817
  _globals['_MODERATEPOSTINPUT_OUTCOME']._serialized_start=2744
  _globals['_MODERATEPOSTINPUT_OUTCOME']._serialized_end=2817
  _globals['_MODERATEPOSTOUTPUT']._serialized_start=2819
  _globals['_MODERATEPOSTOUTPUT']._serialized_end=2839
  _globals['_DELETEPOSTINPUT']._serialized_start=2841
  _globals['_DELETEPOSTINPUT']._serialized_end=2875
  _globals['_DELETEPOSTOUTPUT']._serialized_start=2877
  _globals['_DELETEPOSTOUTPUT']._serialized_end=2932
  _globals['_VOTEPOSTINPUT']._serialized_start=2934
  _globals['_VOTEPOSTINPUT']._serialized_end=2980
  _globals['_VOTEPOSTOUTPUT']._serialized_start=2982
  _globals['_VOTEPOSTOUTPUT']._serialized_end=3018
  _globals['_TRANSLATEPOSTINPUT']._serialized_start=3020
  _globals['_TRANSLATEPOSTINPUT']._serialized_end=3140
  _globals['_TRANSLATEPOSTOUTPUT']._serialized_start=3142
  _globals['_TRANSLATEPOSTOUTPUT']._serialized_end=3179
  _globals['_DESCRIBEPOSTTRANSLATIONINPUT']._serialized_start=3181
  _globals['_DESCRIBEPOSTTRANSLATIONINPUT']._serialized_end=3299
  _globals['_DESCRIBEPOSTTRANSLATIONOUTPUT']._serialized_start=3301
  _globals['_DESCRIBEPOSTTRANSLATIONOUTPUT']._serialized_end=3390
  _globals['_LISTPOSTTRANSLATIONSINPUT']._serialized_start=3393
  _globals['_LISTPOSTTRANSLATIONSINPUT']._serialized_end=3703
  _globals['_LISTPOSTTRANSLATIONSINPUT_FILTER']._serialized_start=3586
  _globals['_LISTPOSTTRANSLATIONSINPUT_FILTER']._serialized_end=3703
  _globals['_LISTPOSTTRANSLATIONSOUTPUT']._serialized_start=3705
  _globals['_LISTPOSTTRANSLATIONSOUTPUT']._serialized_end=3800
  _globals['_CREATEPOSTTRANSLATIONINPUT']._serialized_start=3802
  _globals['_CREATEPOSTTRANSLATIONINPUT']._serialized_end=3905
  _globals['_CREATEPOSTTRANSLATIONOUTPUT']._serialized_start=3907
  _globals['_CREATEPOSTTRANSLATIONOUTPUT']._serialized_end=3960
  _globals['_UPDATEPOSTTRANSLATIONINPUT']._serialized_start=3963
  _globals['_UPDATEPOSTTRANSLATIONINPUT']._serialized_end=4213
  _globals['_UPDATEPOSTTRANSLATIONINPUT_PATCH']._serialized_start=4160
  _globals['_UPDATEPOSTTRANSLATIONINPUT_PATCH']._serialized_end=4213
  _globals['_UPDATEPOSTTRANSLATIONOUTPUT']._serialized_start=4215
  _globals['_UPDATEPOSTTRANSLATIONOUTPUT']._serialized_end=4244
  _globals['_DELETEPOSTTRANSLATIONINPUT']._serialized_start=4246
  _globals['_DELETEPOSTTRANSLATIONINPUT']._serialized_end=4315
  _globals['_DELETEPOSTTRANSLATIONOUTPUT']._serialized_start=4317
  _globals['_DELETEPOSTTRANSLATIONOUTPUT']._serialized_end=4346
  _globals['_POSTSERVICE']._serialized_start=4349
  _globals['_POSTSERVICE']._serialized_end=7084
# @@protoc_insertion_point(module_scope)
