# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/usage.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/executor/usage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/executor/usage.proto\x12\x0f\x65olymp.executor\"\x95\x02\n\rResourceUsage\x12\x15\n\ruser_cpu_time\x18\x01 \x01(\r\x12\x17\n\x0fsystem_cpu_time\x18\x02 \x01(\r\x12\x1d\n\x15max_resident_set_size\x18\x03 \x01(\r\x12\x15\n\rpage_reclaims\x18\x04 \x01(\r\x12\x13\n\x0bpage_faults\x18\x05 \x01(\r\x12\x1e\n\x16\x62lock_input_operations\x18\x06 \x01(\r\x12\x1f\n\x17\x62lock_output_operations\x18\x07 \x01(\r\x12\"\n\x1avoluntary_context_switches\x18\x08 \x01(\r\x12$\n\x1cinvoluntary_context_switches\x18\t \x01(\rB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.usage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_RESOURCEUSAGE']._serialized_start=49
  _globals['_RESOURCEUSAGE']._serialized_end=326
# @@protoc_insertion_point(module_scope)
