# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/l10n/project_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/l10n/project_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.l10n import project_pb2 as eolymp_dot_l10n_dot_project__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/l10n/project_service.proto\x12\x0b\x65olymp.l10n\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/l10n/project.proto\x1a!eolymp/wellknown/expression.proto\"\x9f\x01\n\x11ListProjectsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.l10n.ListProjectsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"H\n\x12ListProjectsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.l10n.Project\"*\n\x14\x44\x65scribeProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\">\n\x15\x44\x65scribeProjectOutput\x12%\n\x07project\x18\x01 \x01(\x0b\x32\x14.eolymp.l10n.Project2\xc0\x02\n\x0eProjectService\x12\x8a\x01\n\x0cListProjects\x12\x1e.eolymp.l10n.ListProjectsInput\x1a\x1f.eolymp.l10n.ListProjectsOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x15\x8a\xe3\n\x11l10n:project:read\x82\xd3\xe4\x93\x02\x0b\x12\t/projects\x12\xa0\x01\n\x0f\x44\x65scribeProject\x12!.eolymp.l10n.DescribeProjectInput\x1a\".eolymp.l10n.DescribeProjectOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x15\x8a\xe3\n\x11l10n:project:read\x82\xd3\xe4\x93\x02\x18\x12\x16/projects/{project_id}B+Z)github.com/eolymp/go-sdk/eolymp/l10n;l10nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.l10n.project_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/l10n;l10n'
  _globals['_PROJECTSERVICE'].methods_by_name['ListProjects']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['ListProjects']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\025\212\343\n\021l10n:project:read\202\323\344\223\002\013\022\t/projects'
  _globals['_PROJECTSERVICE'].methods_by_name['DescribeProject']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['DescribeProject']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\025\212\343\n\021l10n:project:read\202\323\344\223\002\030\022\026/projects/{project_id}'
  _globals['_LISTPROJECTSINPUT']._serialized_start=212
  _globals['_LISTPROJECTSINPUT']._serialized_end=371
  _globals['_LISTPROJECTSINPUT_FILTER']._serialized_start=319
  _globals['_LISTPROJECTSINPUT_FILTER']._serialized_end=371
  _globals['_LISTPROJECTSOUTPUT']._serialized_start=373
  _globals['_LISTPROJECTSOUTPUT']._serialized_end=445
  _globals['_DESCRIBEPROJECTINPUT']._serialized_start=447
  _globals['_DESCRIBEPROJECTINPUT']._serialized_end=489
  _globals['_DESCRIBEPROJECTOUTPUT']._serialized_start=491
  _globals['_DESCRIBEPROJECTOUTPUT']._serialized_end=553
  _globals['_PROJECTSERVICE']._serialized_start=556
  _globals['_PROJECTSERVICE']._serialized_end=876
# @@protoc_insertion_point(module_scope)
