# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/participant_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/judge/participant_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import result_pb2 as eolymp_dot_judge_dot_result__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/judge/participant_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x1e\x65olymp/judge/participant.proto\x1a\x19\x65olymp/judge/result.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x82\x01\n\x17ParticipantChangedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12)\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\x12(\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\\\n\x16ParticipantJoinedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12.\n\x0bparticipant\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\x85\x01\n\x19ParticipantFinalizedEvent\x12\x12\n\ncontest_id\x18\n \x01(\t\x12.\n\x0bparticipant\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\x12$\n\x06result\x18\x03 \x01(\x0b\x32\x14.eolymp.judge.Result\"\x91\x02\n\x16\x41ssignParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x13\n\tmember_id\x18\n \x01(\tH\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12;\n\x05ghost\x18\x0c \x01(\x0b\x32*.eolymp.judge.AssignParticipantInput.GhostH\x00\x12\x12\n\nunofficial\x18\x14 \x01(\x08\x12\x10\n\x08inactive\x18\x15 \x01(\x08\x12,\n\x04role\x18\x1e \x01(\x0e\x32\x1e.eolymp.judge.Participant.Role\x1a\x1d\n\x05Ghost\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\tB\n\n\x08\x61ssignee\"1\n\x17\x41ssignParticipantOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"D\n\x16\x45nableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17\x45nableParticipantOutput\"E\n\x17\x44isableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x1a\n\x18\x44isableParticipantOutput\"\xaa\x01\n\x16UpdateParticipantInput\x12\x34\n\x05patch\x18\x03 \x03(\x0e\x32%.eolymp.judge.Participant.Patch.Field\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x0bparticipant\x18\x04 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\x19\n\x17UpdateParticipantOutput\"\x81\x01\n\x1a\x44isqualifyParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x12\n\ndisqualify\x18\x03 \x01(\x08\x12#\n\x06reason\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x1d\n\x1b\x44isqualifyParticipantOutput\"D\n\x16\x44\x65leteParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteParticipantOutput\"F\n\x18\x44\x65scribeParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"K\n\x19\x44\x65scribeParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\xff\x06\n\x15ListParticipantsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.judge.ListParticipantsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.judge.ListParticipantsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xc3\x04\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x34\n\nunofficial\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x36\n\x0c\x64isqualified\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08inactive\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x04role\x18\r \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12/\n\x05staff\x18\x0e \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x38\n\x0ehas_violations\x18\x0f \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"9\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x0c\x44ISPLAY_NAME\x10\x01\x12\x0e\n\nSTARTED_AT\x10\x02\"Q\n\x16ListParticipantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.judge.Participant\"C\n\x15WatchParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"H\n\x16WatchParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\")\n\x13\x44\x65scribeViewerInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"F\n\x14\x44\x65scribeViewerOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"&\n\x10JoinContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11JoinContestOutput\"\'\n\x11StartContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12StartContestOutput\"\'\n\x11PauseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12PauseContestOutput\"(\n\x12\x46inishContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x46inishContestOutput2\xcb\x11\n\x12ParticipantService\x12\xa1\x01\n\x11\x41ssignParticipant\x12$.eolymp.judge.AssignParticipantInput\x1a%.eolymp.judge.AssignParticipantOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x0f\"\r/participants\x12\xb9\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\'\"%/participants/{participant_id}/enable\x12\xbd\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02(\"&/participants/{participant_id}/disable\x12\xb2\x01\n\x11UpdateParticipant\x12$.eolymp.judge.UpdateParticipantInput\x1a%.eolymp.judge.UpdateParticipantOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 \x1a\x1e/participants/{participant_id}\x12\xc9\x01\n\x15\x44isqualifyParticipant\x12(.eolymp.judge.DisqualifyParticipantInput\x1a).eolymp.judge.DisqualifyParticipantOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02+\")/participants/{participant_id}/disqualify\x12\xb2\x01\n\x11\x44\x65leteParticipant\x12$.eolymp.judge.DeleteParticipantInput\x1a%.eolymp.judge.DeleteParticipantOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 *\x1e/participants/{participant_id}\x12\xb8\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"P\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02 \x12\x1e/participants/{participant_id}\x12\x9d\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x0f\x12\r/participants\x12{\n\x10WatchParticipant\x12#.eolymp.judge.WatchParticipantInput\x1a$.eolymp.judge.WatchParticipantOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12l\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x07\"\x05/join\x12{\n\x0e\x44\x65scribeViewer\x12!.eolymp.judge.DescribeViewerInput\x1a\".eolymp.judge.DescribeViewerOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/introspect\x12\x91\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x08\"\x06/start\x12\x91\x01\n\x0cPauseContest\x12\x1f.eolymp.judge.PauseContestInput\x1a .eolymp.judge.PauseContestOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x08\"\x06/pause\x12t\n\rFinishContest\x12 .eolymp.judge.FinishContestInput\x1a!.eolymp.judge.FinishContestOutput\"\x1e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\t\x12\x07/finishB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.participant_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['AssignParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['AssignParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\017\"\r/participants'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['EnableParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['EnableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\'\"%/participants/{participant_id}/enable'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisableParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002(\"&/participants/{participant_id}/disable'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['UpdateParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['UpdateParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 \032\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisqualifyParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisqualifyParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002+\")/participants/{participant_id}/disqualify'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DeleteParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DeleteParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 *\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeParticipant']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002 \022\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['ListParticipants']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['ListParticipants']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\017\022\r/participants'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['WatchParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['WatchParticipant']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['JoinContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['JoinContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\007\"\005/join'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeViewer']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeViewer']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/introspect'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['StartContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['StartContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\010\"\006/start'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['PauseContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['PauseContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\010\"\006/pause'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['FinishContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['FinishContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\t\022\007/finish'
  _globals['_PARTICIPANTCHANGEDEVENT']._serialized_start=310
  _globals['_PARTICIPANTCHANGEDEVENT']._serialized_end=440
  _globals['_PARTICIPANTJOINEDEVENT']._serialized_start=442
  _globals['_PARTICIPANTJOINEDEVENT']._serialized_end=534
  _globals['_PARTICIPANTFINALIZEDEVENT']._serialized_start=537
  _globals['_PARTICIPANTFINALIZEDEVENT']._serialized_end=670
  _globals['_ASSIGNPARTICIPANTINPUT']._serialized_start=673
  _globals['_ASSIGNPARTICIPANTINPUT']._serialized_end=946
  _globals['_ASSIGNPARTICIPANTINPUT_GHOST']._serialized_start=905
  _globals['_ASSIGNPARTICIPANTINPUT_GHOST']._serialized_end=934
  _globals['_ASSIGNPARTICIPANTOUTPUT']._serialized_start=948
  _globals['_ASSIGNPARTICIPANTOUTPUT']._serialized_end=997
  _globals['_ENABLEPARTICIPANTINPUT']._serialized_start=999
  _globals['_ENABLEPARTICIPANTINPUT']._serialized_end=1067
  _globals['_ENABLEPARTICIPANTOUTPUT']._serialized_start=1069
  _globals['_ENABLEPARTICIPANTOUTPUT']._serialized_end=1094
  _globals['_DISABLEPARTICIPANTINPUT']._serialized_start=1096
  _globals['_DISABLEPARTICIPANTINPUT']._serialized_end=1165
  _globals['_DISABLEPARTICIPANTOUTPUT']._serialized_start=1167
  _globals['_DISABLEPARTICIPANTOUTPUT']._serialized_end=1193
  _globals['_UPDATEPARTICIPANTINPUT']._serialized_start=1196
  _globals['_UPDATEPARTICIPANTINPUT']._serialized_end=1366
  _globals['_UPDATEPARTICIPANTOUTPUT']._serialized_start=1368
  _globals['_UPDATEPARTICIPANTOUTPUT']._serialized_end=1393
  _globals['_DISQUALIFYPARTICIPANTINPUT']._serialized_start=1396
  _globals['_DISQUALIFYPARTICIPANTINPUT']._serialized_end=1525
  _globals['_DISQUALIFYPARTICIPANTOUTPUT']._serialized_start=1527
  _globals['_DISQUALIFYPARTICIPANTOUTPUT']._serialized_end=1556
  _globals['_DELETEPARTICIPANTINPUT']._serialized_start=1558
  _globals['_DELETEPARTICIPANTINPUT']._serialized_end=1626
  _globals['_DELETEPARTICIPANTOUTPUT']._serialized_start=1628
  _globals['_DELETEPARTICIPANTOUTPUT']._serialized_end=1653
  _globals['_DESCRIBEPARTICIPANTINPUT']._serialized_start=1655
  _globals['_DESCRIBEPARTICIPANTINPUT']._serialized_end=1725
  _globals['_DESCRIBEPARTICIPANTOUTPUT']._serialized_start=1727
  _globals['_DESCRIBEPARTICIPANTOUTPUT']._serialized_end=1802
  _globals['_LISTPARTICIPANTSINPUT']._serialized_start=1805
  _globals['_LISTPARTICIPANTSINPUT']._serialized_end=2700
  _globals['_LISTPARTICIPANTSINPUT_FILTER']._serialized_start=2062
  _globals['_LISTPARTICIPANTSINPUT_FILTER']._serialized_end=2641
  _globals['_LISTPARTICIPANTSINPUT_SORTABLE']._serialized_start=2643
  _globals['_LISTPARTICIPANTSINPUT_SORTABLE']._serialized_end=2700
  _globals['_LISTPARTICIPANTSOUTPUT']._serialized_start=2702
  _globals['_LISTPARTICIPANTSOUTPUT']._serialized_end=2783
  _globals['_WATCHPARTICIPANTINPUT']._serialized_start=2785
  _globals['_WATCHPARTICIPANTINPUT']._serialized_end=2852
  _globals['_WATCHPARTICIPANTOUTPUT']._serialized_start=2854
  _globals['_WATCHPARTICIPANTOUTPUT']._serialized_end=2926
  _globals['_DESCRIBEVIEWERINPUT']._serialized_start=2928
  _globals['_DESCRIBEVIEWERINPUT']._serialized_end=2969
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_start=2971
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_end=3041
  _globals['_JOINCONTESTINPUT']._serialized_start=3043
  _globals['_JOINCONTESTINPUT']._serialized_end=3081
  _globals['_JOINCONTESTOUTPUT']._serialized_start=3083
  _globals['_JOINCONTESTOUTPUT']._serialized_end=3102
  _globals['_STARTCONTESTINPUT']._serialized_start=3104
  _globals['_STARTCONTESTINPUT']._serialized_end=3143
  _globals['_STARTCONTESTOUTPUT']._serialized_start=3145
  _globals['_STARTCONTESTOUTPUT']._serialized_end=3165
  _globals['_PAUSECONTESTINPUT']._serialized_start=3167
  _globals['_PAUSECONTESTINPUT']._serialized_end=3206
  _globals['_PAUSECONTESTOUTPUT']._serialized_start=3208
  _globals['_PAUSECONTESTOUTPUT']._serialized_end=3228
  _globals['_FINISHCONTESTINPUT']._serialized_start=3230
  _globals['_FINISHCONTESTINPUT']._serialized_end=3270
  _globals['_FINISHCONTESTOUTPUT']._serialized_start=3272
  _globals['_FINISHCONTESTOUTPUT']._serialized_end=3293
  _globals['_PARTICIPANTSERVICE']._serialized_start=3296
  _globals['_PARTICIPANTSERVICE']._serialized_end=5547
# @@protoc_insertion_point(module_scope)
