# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/suggestion_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/suggestion_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.atlas import suggestion_pb2 as eolymp_dot_atlas_dot_suggestion__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/atlas/suggestion_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1d\x65olymp/atlas/suggestion.proto\x1a\x18\x65olymp/ecm/content.proto\x1a!eolymp/wellknown/expression.proto\"\x7f\n\x16SuggestionChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\x12\'\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\"E\n\x15\x43reateSuggestionInput\x12,\n\nsuggestion\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\"/\n\x16\x43reateSuggestionOutput\x12\x15\n\rsuggestion_id\x18\x01 \x01(\t\"\\\n\x15UpdateSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\x12,\n\nsuggestion\x18\x03 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion\"\x18\n\x16UpdateSuggestionOutput\".\n\x15\x44\x65leteSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteSuggestionOutput\"\x85\x01\n\x15ReviewSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\x12/\n\x06status\x18\x03 \x01(\x0e\x32\x1f.eolymp.atlas.Suggestion.Status\x12$\n\x07\x63omment\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x18\n\x16ReviewSuggestionOutput\"0\n\x17ResubmitSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\"\x1a\n\x18ResubmitSuggestionOutput\"\x8c\x02\n\x14ListSuggestionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.atlas.ListSuggestionsInput.Filter\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListSuggestionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Suggestion\"0\n\x17\x44\x65scribeSuggestionInput\x12\x15\n\rsuggestion_id\x18\x02 \x01(\t\"H\n\x18\x44\x65scribeSuggestionOutput\x12,\n\nsuggestion\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Suggestion2\x9e\x08\n\x11SuggestionService\x12\x82\x01\n\x10\x43reateSuggestion\x12#.eolymp.atlas.CreateSuggestionInput\x1a$.eolymp.atlas.CreateSuggestionOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\"\x0c/suggestions\x12\x92\x01\n\x10UpdateSuggestion\x12#.eolymp.atlas.UpdateSuggestionInput\x1a$.eolymp.atlas.UpdateSuggestionOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/suggestions/{suggestion_id}\x12\x99\x01\n\x10ReviewSuggestion\x12#.eolymp.atlas.ReviewSuggestionInput\x1a$.eolymp.atlas.ReviewSuggestionOutput\":\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\"#/suggestions/{suggestion_id}/review\x12\xa1\x01\n\x12ResubmitSuggestion\x12%.eolymp.atlas.ResubmitSuggestionInput\x1a&.eolymp.atlas.ResubmitSuggestionOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\'\"%/suggestions/{suggestion_id}/resubmit\x12\x92\x01\n\x10\x44\x65leteSuggestion\x12#.eolymp.atlas.DeleteSuggestionInput\x1a$.eolymp.atlas.DeleteSuggestionOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/suggestions/{suggestion_id}\x12\x7f\n\x0fListSuggestions\x12\".eolymp.atlas.ListSuggestionsInput\x1a#.eolymp.atlas.ListSuggestionsOutput\"#\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/suggestions\x12\x98\x01\n\x12\x44\x65scribeSuggestion\x12%.eolymp.atlas.DescribeSuggestionInput\x1a&.eolymp.atlas.DescribeSuggestionOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/suggestions/{suggestion_id}B-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.suggestion_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['CreateSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['CreateSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\016\"\014/suggestions'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['UpdateSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['UpdateSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036\"\034/suggestions/{suggestion_id}'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ReviewSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ReviewSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002%\"#/suggestions/{suggestion_id}/review'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ResubmitSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ResubmitSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\'\"%/suggestions/{suggestion_id}/resubmit'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DeleteSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DeleteSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036*\034/suggestions/{suggestion_id}'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ListSuggestions']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['ListSuggestions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/suggestions'
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DescribeSuggestion']._loaded_options = None
  _globals['_SUGGESTIONSERVICE'].methods_by_name['DescribeSuggestion']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/suggestions/{suggestion_id}'
  _globals['_SUGGESTIONCHANGEDEVENT']._serialized_start=214
  _globals['_SUGGESTIONCHANGEDEVENT']._serialized_end=341
  _globals['_CREATESUGGESTIONINPUT']._serialized_start=343
  _globals['_CREATESUGGESTIONINPUT']._serialized_end=412
  _globals['_CREATESUGGESTIONOUTPUT']._serialized_start=414
  _globals['_CREATESUGGESTIONOUTPUT']._serialized_end=461
  _globals['_UPDATESUGGESTIONINPUT']._serialized_start=463
  _globals['_UPDATESUGGESTIONINPUT']._serialized_end=555
  _globals['_UPDATESUGGESTIONOUTPUT']._serialized_start=557
  _globals['_UPDATESUGGESTIONOUTPUT']._serialized_end=581
  _globals['_DELETESUGGESTIONINPUT']._serialized_start=583
  _globals['_DELETESUGGESTIONINPUT']._serialized_end=629
  _globals['_DELETESUGGESTIONOUTPUT']._serialized_start=631
  _globals['_DELETESUGGESTIONOUTPUT']._serialized_end=655
  _globals['_REVIEWSUGGESTIONINPUT']._serialized_start=658
  _globals['_REVIEWSUGGESTIONINPUT']._serialized_end=791
  _globals['_REVIEWSUGGESTIONOUTPUT']._serialized_start=793
  _globals['_REVIEWSUGGESTIONOUTPUT']._serialized_end=817
  _globals['_RESUBMITSUGGESTIONINPUT']._serialized_start=819
  _globals['_RESUBMITSUGGESTIONINPUT']._serialized_end=867
  _globals['_RESUBMITSUGGESTIONOUTPUT']._serialized_start=869
  _globals['_RESUBMITSUGGESTIONOUTPUT']._serialized_end=895
  _globals['_LISTSUGGESTIONSINPUT']._serialized_start=898
  _globals['_LISTSUGGESTIONSINPUT']._serialized_end=1166
  _globals['_LISTSUGGESTIONSINPUT_FILTER']._serialized_start=1013
  _globals['_LISTSUGGESTIONSINPUT_FILTER']._serialized_end=1166
  _globals['_LISTSUGGESTIONSOUTPUT']._serialized_start=1168
  _globals['_LISTSUGGESTIONSOUTPUT']._serialized_end=1247
  _globals['_DESCRIBESUGGESTIONINPUT']._serialized_start=1249
  _globals['_DESCRIBESUGGESTIONINPUT']._serialized_end=1297
  _globals['_DESCRIBESUGGESTIONOUTPUT']._serialized_start=1299
  _globals['_DESCRIBESUGGESTIONOUTPUT']._serialized_end=1371
  _globals['_SUGGESTIONSERVICE']._serialized_start=1374
  _globals['_SUGGESTIONSERVICE']._serialized_end=2428
# @@protoc_insertion_point(module_scope)
