# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/events.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.course import assignment_pb2 as eolymp_dot_course_dot_assignment__pb2
from eolymp.course import material_pb2 as eolymp_dot_course_dot_material__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.course import student_pb2 as eolymp_dot_course_dot_student__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/course/events.proto\x12\reolymp.course\x1a\x1e\x65olymp/course/assignment.proto\x1a\x1c\x65olymp/course/material.proto\x1a\x1a\x65olymp/course/module.proto\x1a\x1b\x65olymp/course/student.proto\"t\n\x12ModuleChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12%\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x15.eolymp.course.Module\x12$\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Module\"z\n\x14MaterialChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12\'\n\x06\x62\x65\x66ore\x18\x03 \x01(\x0b\x32\x17.eolymp.course.Material\x12&\n\x05\x61\x66ter\x18\x04 \x01(\x0b\x32\x17.eolymp.course.Material\"w\n\x13StudentChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12&\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x16.eolymp.course.Student\x12%\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x16.eolymp.course.Student\"\x93\x01\n\x16\x41ssignmentChangedEvent\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12)\n\x06\x62\x65\x66ore\x18\x03 \x01(\x0b\x32\x19.eolymp.course.Assignment\x12(\n\x05\x61\x66ter\x18\x04 \x01(\x0b\x32\x19.eolymp.course.AssignmentB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_MODULECHANGEDEVENT']._serialized_start=164
  _globals['_MODULECHANGEDEVENT']._serialized_end=280
  _globals['_MATERIALCHANGEDEVENT']._serialized_start=282
  _globals['_MATERIALCHANGEDEVENT']._serialized_end=404
  _globals['_STUDENTCHANGEDEVENT']._serialized_start=406
  _globals['_STUDENTCHANGEDEVENT']._serialized_end=525
  _globals['_ASSIGNMENTCHANGEDEVENT']._serialized_start=528
  _globals['_ASSIGNMENTCHANGEDEVENT']._serialized_end=675
# @@protoc_insertion_point(module_scope)
