# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ViolationServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateViolation(self, request, **kwargs):
        path = "/violations"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateViolationOutput"),
            **kwargs,
        )

    def UpdateViolation(self, request, **kwargs):
        path = "/violations/"+urllib.parse.quote(request.violation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.violation_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateViolationOutput"),
            **kwargs,
        )

    def DeleteViolation(self, request, **kwargs):
        path = "/violations/"+urllib.parse.quote(request.violation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.violation_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteViolationOutput"),
            **kwargs,
        )

    def DescribeViolation(self, request, **kwargs):
        path = "/violations/"+urllib.parse.quote(request.violation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.violation_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeViolationOutput"),
            **kwargs,
        )

    def ListViolations(self, request, **kwargs):
        path = "/violations"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListViolationsOutput"),
            **kwargs,
        )

