# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/notify/preferences.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/notify/preferences.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/notify/preferences.proto\x12\reolymp.notify\"\xe3\x01\n\x0bPreferences\x12>\n\rsubscriptions\x18\n \x03(\x0b\x32\'.eolymp.notify.Preferences.Subscription\x1aP\n\x0cSubscription\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x31\n\x06\x64igest\x18\x02 \x01(\x0e\x32!.eolymp.notify.Preferences.Digest\"B\n\x06\x44igest\x12\x12\n\x0eUNKNOWN_DIGEST\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\n\n\x06HOURLY\x10\x02\x12\t\n\x05\x44\x41ILY\x10\x03\x42/Z-github.com/eolymp/go-sdk/eolymp/notify;notifyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.notify.preferences_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/notify;notify'
  _globals['_PREFERENCES']._serialized_start=51
  _globals['_PREFERENCES']._serialized_end=278
  _globals['_PREFERENCES_SUBSCRIPTION']._serialized_start=130
  _globals['_PREFERENCES_SUBSCRIPTION']._serialized_end=210
  _globals['_PREFERENCES_DIGEST']._serialized_start=212
  _globals['_PREFERENCES_DIGEST']._serialized_end=278
# @@protoc_insertion_point(module_scope)
