# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/product.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/product.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/commerce/product.proto\x12\x0f\x65olymp.commerce\x1a\x18\x65olymp/ecm/content.proto\"\xcf\x05\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x0e\n\x06images\x18\n \x03(\t\x12\x14\n\x0cout_of_stock\x18\x1e \x01(\x08\x12\x10\n\x08\x63urrency\x18\x14 \x01(\t\x12\x12\n\nunit_price\x18\x15 \x01(\r\x12\x36\n\nattributes\x18( \x03(\x0b\x32\".eolymp.commerce.Product.Attribute\x12\x32\n\x08variants\x18\x32 \x03(\x0b\x32 .eolymp.commerce.Product.Variant\x1ap\n\x05\x45xtra\"g\n\x05\x46ield\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x01\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x02\x12\x0e\n\nATTRIBUTES\x10\x03\x12\x0c\n\x08VARIANTS\x10\x04\x1a\x81\x01\n\x05Patch\"x\n\x05\x46ield\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x03\x12\n\n\x06IMAGES\x10\x04\x12\x0e\n\nUNIT_PRICE\x10\x05\x12\x0e\n\nATTRIBUTES\x10\x07\x12\x0c\n\x08VARIANTS\x10\x08\x1a\'\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x1a\xa8\x01\n\x07Variant\x12\n\n\x02id\x18\x01 \x01(\t\x12<\n\x06values\x18\x02 \x03(\x0b\x32,.eolymp.commerce.Product.Variant.ValuesEntry\x12\x0e\n\x06images\x18\n \x03(\t\x12\x14\n\x0cout_of_stock\x18\x1e \x01(\x08\x1a-\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.product_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._loaded_options = None
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._serialized_options = b'8\001'
  _globals['_PRODUCT']._serialized_start=77
  _globals['_PRODUCT']._serialized_end=796
  _globals['_PRODUCT_EXTRA']._serialized_start=340
  _globals['_PRODUCT_EXTRA']._serialized_end=452
  _globals['_PRODUCT_EXTRA_FIELD']._serialized_start=349
  _globals['_PRODUCT_EXTRA_FIELD']._serialized_end=452
  _globals['_PRODUCT_PATCH']._serialized_start=455
  _globals['_PRODUCT_PATCH']._serialized_end=584
  _globals['_PRODUCT_PATCH_FIELD']._serialized_start=464
  _globals['_PRODUCT_PATCH_FIELD']._serialized_end=584
  _globals['_PRODUCT_ATTRIBUTE']._serialized_start=586
  _globals['_PRODUCT_ATTRIBUTE']._serialized_end=625
  _globals['_PRODUCT_VARIANT']._serialized_start=628
  _globals['_PRODUCT_VARIANT']._serialized_end=796
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._serialized_start=751
  _globals['_PRODUCT_VARIANT_VALUESENTRY']._serialized_end=796
# @@protoc_insertion_point(module_scope)
