# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ranker/ranker.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/ranker/ranker.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ranker import activity_pb2 as eolymp_dot_ranker_dot_activity__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.ranker import scoreboard_service_pb2 as eolymp_dot_ranker_dot_scoreboard__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/ranker/activity.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a&eolymp/ranker/scoreboard_service.proto\"J\n\x13ListActivitiesInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.ranker.Activity\"^\n\x13ScheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Action\")\n\x14ScheduleActionOutput\x12\x11\n\taction_id\x18\x01 \x01(\t\"A\n\x15UnscheduleActionInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\taction_id\x18\x02 \x01(\t\"\x18\n\x16UnscheduleActionOutput\"2\n\x19ListScheduledActionsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\\\n\x1aListScheduledActionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Action2\xfe\x19\n\x06Ranker\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16UpdateScoreboardColumn\x12*.eolymp.ranker.UpdateScoreboardColumnInput\x1a+.eolymp.ranker.UpdateScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32\x1a\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columns\x12\xb3\x01\n\x0eListActivities\x12\".eolymp.ranker.ListActivitiesInput\x1a#.eolymp.ranker.ListActivitiesOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02)\x12\'/scoreboards/{scoreboard_id}/activities\x12\xb6\x01\n\x0eScheduleAction\x12\".eolymp.ranker.ScheduleActionInput\x1a#.eolymp.ranker.ScheduleActionOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\'\"%/scoreboards/{scoreboard_id}/schedule\x12\xc8\x01\n\x10UnscheduleAction\x12$.eolymp.ranker.UnscheduleActionInput\x1a%.eolymp.ranker.UnscheduleActionOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x33*1/scoreboards/{scoreboard_id}/schedule/{action_id}\x12\xc8\x01\n\x14ListScheduledActions\x12(.eolymp.ranker.ListScheduledActionsInput\x1a).eolymp.ranker.ListScheduledActionsOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\'\x12%/scoreboards/{scoreboard_id}/scheduleB/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.ranker_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _globals['_RANKER'].methods_by_name['CreateScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['CreateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\016\"\014/scoreboards'
  _globals['_RANKER'].methods_by_name['UpdateScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['UpdateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _globals['_RANKER'].methods_by_name['RebuildScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['RebuildScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _globals['_RANKER'].methods_by_name['DeleteScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DeleteScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _globals['_RANKER'].methods_by_name['DescribeScoreboard']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DescribeScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _globals['_RANKER'].methods_by_name['ListScoreboards']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScoreboards']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\016\022\014/scoreboards'
  _globals['_RANKER'].methods_by_name['DescribeScoreboardRow']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DescribeScoreboardRow']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _globals['_RANKER'].methods_by_name['ListScoreboardRows']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScoreboardRows']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _globals['_RANKER'].methods_by_name['AddScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['AddScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _globals['_RANKER'].methods_by_name['UpdateScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['UpdateScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022\0320/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_RANKER'].methods_by_name['DeleteScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_RANKER'].methods_by_name['DescribeScoreboardColumn']._loaded_options = None
  _globals['_RANKER'].methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_RANKER'].methods_by_name['ListScoreboardColumns']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScoreboardColumns']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _globals['_RANKER'].methods_by_name['ListActivities']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListActivities']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002)\022\'/scoreboards/{scoreboard_id}/activities'
  _globals['_RANKER'].methods_by_name['ScheduleAction']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ScheduleAction']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\'\"%/scoreboards/{scoreboard_id}/schedule'
  _globals['_RANKER'].methods_by_name['UnscheduleAction']._loaded_options = None
  _globals['_RANKER'].methods_by_name['UnscheduleAction']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0023*1/scoreboards/{scoreboard_id}/schedule/{action_id}'
  _globals['_RANKER'].methods_by_name['ListScheduledActions']._loaded_options = None
  _globals['_RANKER'].methods_by_name['ListScheduledActions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\'\022%/scoreboards/{scoreboard_id}/schedule'
  _globals['_LISTACTIVITIESINPUT']._serialized_start=246
  _globals['_LISTACTIVITIESINPUT']._serialized_end=320
  _globals['_LISTACTIVITIESOUTPUT']._serialized_start=322
  _globals['_LISTACTIVITIESOUTPUT']._serialized_end=399
  _globals['_SCHEDULEACTIONINPUT']._serialized_start=401
  _globals['_SCHEDULEACTIONINPUT']._serialized_end=495
  _globals['_SCHEDULEACTIONOUTPUT']._serialized_start=497
  _globals['_SCHEDULEACTIONOUTPUT']._serialized_end=538
  _globals['_UNSCHEDULEACTIONINPUT']._serialized_start=540
  _globals['_UNSCHEDULEACTIONINPUT']._serialized_end=605
  _globals['_UNSCHEDULEACTIONOUTPUT']._serialized_start=607
  _globals['_UNSCHEDULEACTIONOUTPUT']._serialized_end=631
  _globals['_LISTSCHEDULEDACTIONSINPUT']._serialized_start=633
  _globals['_LISTSCHEDULEDACTIONSINPUT']._serialized_end=683
  _globals['_LISTSCHEDULEDACTIONSOUTPUT']._serialized_start=685
  _globals['_LISTSCHEDULEDACTIONSOUTPUT']._serialized_end=777
  _globals['_RANKER']._serialized_start=780
  _globals['_RANKER']._serialized_end=4106
# @@protoc_insertion_point(module_scope)
