# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/thread_endpoint.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/thread_endpoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.discussion import thread_pb2 as eolymp_dot_discussion_dot_thread__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/discussion/thread_endpoint.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/discussion/thread.proto\"%\n\x13\x44\x65scribeThreadInput\x12\x0e\n\x06locale\x18\n \x01(\t\"A\n\x14\x44\x65scribeThreadOutput\x12)\n\x06thread\x18\x01 \x01(\x0b\x32\x19.eolymp.discussion.Thread\"3\n\x0fVoteThreadInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"&\n\x10VoteThreadOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\x32\x81\x02\n\x0eThreadEndpoint\x12z\n\x0e\x44\x65scribeThread\x12&.eolymp.discussion.DescribeThreadInput\x1a\'.eolymp.discussion.DescribeThreadOutput\"\x17\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x02\x12\x00\x12s\n\nVoteThread\x12\".eolymp.discussion.VoteThreadInput\x1a#.eolymp.discussion.VoteThreadOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x07\"\x05/voteB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.thread_endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_THREADENDPOINT'].methods_by_name['DescribeThread']._loaded_options = None
  _globals['_THREADENDPOINT'].methods_by_name['DescribeThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\002\022\000'
  _globals['_THREADENDPOINT'].methods_by_name['VoteThread']._loaded_options = None
  _globals['_THREADENDPOINT'].methods_by_name['VoteThread']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\007\"\005/vote'
  _globals['_DESCRIBETHREADINPUT']._serialized_start=161
  _globals['_DESCRIBETHREADINPUT']._serialized_end=198
  _globals['_DESCRIBETHREADOUTPUT']._serialized_start=200
  _globals['_DESCRIBETHREADOUTPUT']._serialized_end=265
  _globals['_VOTETHREADINPUT']._serialized_start=267
  _globals['_VOTETHREADINPUT']._serialized_end=318
  _globals['_VOTETHREADOUTPUT']._serialized_start=320
  _globals['_VOTETHREADOUTPUT']._serialized_end=358
  _globals['_THREADENDPOINT']._serialized_start=361
  _globals['_THREADENDPOINT']._serialized_end=618
# @@protoc_insertion_point(module_scope)
