# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/annotations/endpoint.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/annotations/endpoint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/annotations/endpoint.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"a\n\x08\x45ndpoint\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12-\n\x07service\x18\x02 \x03(\x0b\x32\x1c.eolymp.api.Endpoint.Service\x1a\x17\n\x07Service\x12\x0c\n\x04name\x18\x01 \x01(\t:I\n\x08\x65ndpoint\x12\x1f.google.protobuf.MessageOptions\x18\xbb\xac\x01 \x01(\x0b\x32\x14.eolymp.api.EndpointB9Z7github.com/eolymp/go-sdk/eolymp/annotations;annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.annotations.endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/annotations;annotations'
  _globals['_ENDPOINT']._serialized_start=83
  _globals['_ENDPOINT']._serialized_end=180
  _globals['_ENDPOINT_SERVICE']._serialized_start=157
  _globals['_ENDPOINT_SERVICE']._serialized_end=180
# @@protoc_insertion_point(module_scope)
