# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/shopping_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/shopping_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.commerce import address_pb2 as eolymp_dot_commerce_dot_address__pb2
from eolymp.commerce import shopping_cart_pb2 as eolymp_dot_commerce_dot_shopping__cart__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/commerce/shopping_service.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/commerce/address.proto\x1a#eolymp/commerce/shopping_cart.proto\"\x1b\n\x19\x44\x65scribeShoppingCartInput\"I\n\x1a\x44\x65scribeShoppingCartOutput\x12+\n\x04\x63\x61rt\x18\x01 \x01(\x0b\x32\x1d.eolymp.commerce.ShoppingCart\"W\n\x1b\x43reateShoppingCartItemInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x12\n\nvariant_id\x18\x02 \x01(\t\x12\x10\n\x08quantity\x18\x03 \x01(\x05\"/\n\x1c\x43reateShoppingCartItemOutput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"@\n\x1bUpdateShoppingCartItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x05\"\x1e\n\x1cUpdateShoppingCartItemOutput\".\n\x1b\x44\x65leteShoppingCartItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"\x1e\n\x1c\x44\x65leteShoppingCartItemOutput\"G\n\x1aUpdateShippingAddressInput\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Address\"\x1d\n\x1bUpdateShippingAddressOutput\"`\n\x19UpdateBillingAddressInput\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Address\x12\x18\n\x10same_as_shipping\x18\x02 \x01(\x08\"\x1c\n\x1aUpdateBillingAddressOutput\"\x11\n\x0fPlaceOrderInput\":\n\x10PlaceOrderOutput\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x14\n\x0corder_number\x18\x02 \x01(\t2\xc7\n\n\x0fShoppingService\x12\xb1\x01\n\x14\x44\x65scribeShoppingCart\x12*.eolymp.commerce.DescribeShoppingCartInput\x1a+.eolymp.commerce.DescribeShoppingCartOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:shopping:read\x82\xd3\xe4\x93\x02\r\x12\x0b/store/cart\x12\xbe\x01\n\x16\x43reateShoppingCartItem\x12,.eolymp.commerce.CreateShoppingCartItemInput\x1a-.eolymp.commerce.CreateShoppingCartItemOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x13\"\x11/store/cart/items\x12\xc8\x01\n\x16UpdateShoppingCartItem\x12,.eolymp.commerce.UpdateShoppingCartItemInput\x1a-.eolymp.commerce.UpdateShoppingCartItemOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/store/cart/items/{item_id}\x12\xc8\x01\n\x16\x44\x65leteShoppingCartItem\x12,.eolymp.commerce.DeleteShoppingCartItemInput\x1a-.eolymp.commerce.DeleteShoppingCartItemOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1d*\x1b/store/cart/items/{item_id}\x12\xc6\x01\n\x15UpdateShippingAddress\x12+.eolymp.commerce.UpdateShippingAddressInput\x1a,.eolymp.commerce.UpdateShippingAddressOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/store/cart/shipping-address\x12\xc2\x01\n\x14UpdateBillingAddress\x12*.eolymp.commerce.UpdateBillingAddressInput\x1a+.eolymp.commerce.UpdateBillingAddressOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/store/cart/billing-address\x12\x9a\x01\n\nPlaceOrder\x12 .eolymp.commerce.PlaceOrderInput\x1a!.eolymp.commerce.PlaceOrderOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x63ommerce:shopping:write\x82\xd3\xe4\x93\x02\x13\"\x11/store/cart:orderB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.shopping_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_SHOPPINGSERVICE'].methods_by_name['DescribeShoppingCart']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['DescribeShoppingCart']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\032\212\343\n\026commerce:shopping:read\202\323\344\223\002\r\022\013/store/cart'
  _globals['_SHOPPINGSERVICE'].methods_by_name['CreateShoppingCartItem']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['CreateShoppingCartItem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\023\"\021/store/cart/items'
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShoppingCartItem']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShoppingCartItem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\035\032\033/store/cart/items/{item_id}'
  _globals['_SHOPPINGSERVICE'].methods_by_name['DeleteShoppingCartItem']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['DeleteShoppingCartItem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\035*\033/store/cart/items/{item_id}'
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShippingAddress']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateShippingAddress']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\036\"\034/store/cart/shipping-address'
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateBillingAddress']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['UpdateBillingAddress']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\035\"\033/store/cart/billing-address'
  _globals['_SHOPPINGSERVICE'].methods_by_name['PlaceOrder']._loaded_options = None
  _globals['_SHOPPINGSERVICE'].methods_by_name['PlaceOrder']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\033\212\343\n\027commerce:shopping:write\202\323\344\223\002\023\"\021/store/cart:order'
  _globals['_DESCRIBESHOPPINGCARTINPUT']._serialized_start=226
  _globals['_DESCRIBESHOPPINGCARTINPUT']._serialized_end=253
  _globals['_DESCRIBESHOPPINGCARTOUTPUT']._serialized_start=255
  _globals['_DESCRIBESHOPPINGCARTOUTPUT']._serialized_end=328
  _globals['_CREATESHOPPINGCARTITEMINPUT']._serialized_start=330
  _globals['_CREATESHOPPINGCARTITEMINPUT']._serialized_end=417
  _globals['_CREATESHOPPINGCARTITEMOUTPUT']._serialized_start=419
  _globals['_CREATESHOPPINGCARTITEMOUTPUT']._serialized_end=466
  _globals['_UPDATESHOPPINGCARTITEMINPUT']._serialized_start=468
  _globals['_UPDATESHOPPINGCARTITEMINPUT']._serialized_end=532
  _globals['_UPDATESHOPPINGCARTITEMOUTPUT']._serialized_start=534
  _globals['_UPDATESHOPPINGCARTITEMOUTPUT']._serialized_end=564
  _globals['_DELETESHOPPINGCARTITEMINPUT']._serialized_start=566
  _globals['_DELETESHOPPINGCARTITEMINPUT']._serialized_end=612
  _globals['_DELETESHOPPINGCARTITEMOUTPUT']._serialized_start=614
  _globals['_DELETESHOPPINGCARTITEMOUTPUT']._serialized_end=644
  _globals['_UPDATESHIPPINGADDRESSINPUT']._serialized_start=646
  _globals['_UPDATESHIPPINGADDRESSINPUT']._serialized_end=717
  _globals['_UPDATESHIPPINGADDRESSOUTPUT']._serialized_start=719
  _globals['_UPDATESHIPPINGADDRESSOUTPUT']._serialized_end=748
  _globals['_UPDATEBILLINGADDRESSINPUT']._serialized_start=750
  _globals['_UPDATEBILLINGADDRESSINPUT']._serialized_end=846
  _globals['_UPDATEBILLINGADDRESSOUTPUT']._serialized_start=848
  _globals['_UPDATEBILLINGADDRESSOUTPUT']._serialized_end=876
  _globals['_PLACEORDERINPUT']._serialized_start=878
  _globals['_PLACEORDERINPUT']._serialized_end=895
  _globals['_PLACEORDEROUTPUT']._serialized_start=897
  _globals['_PLACEORDEROUTPUT']._serialized_end=955
  _globals['_SHOPPINGSERVICE']._serialized_start=958
  _globals['_SHOPPINGSERVICE']._serialized_end=2309
# @@protoc_insertion_point(module_scope)
