# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/quota.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/quota.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/universe/quota.proto\x12\x0f\x65olymp.universe\"\xa8\t\n\x05Quota\x12\x1d\n\x15permissions_per_space\x18\x06 \x01(\r\x12\x16\n\x0esingle_sing_on\x18\x16 \x01(\x08\x12\x1f\n\x17\x64\x65\x64icated_user_database\x18\x17 \x01(\x08\x12\x1c\n\x14\x61ttributes_per_space\x18\x07 \x01(\r\x12#\n\x1b\x63ustomer_support_reply_time\x18\x18 \x01(\r\x12\x19\n\x11\x61llow_discussions\x18\x1f \x01(\x08\x12\x1e\n\x16\x61\x63hievements_per_space\x18\x0f \x01(\r\x12\x1a\n\x12printers_per_space\x18\x1a \x01(\r\x12%\n\x1d\x65valuations_by_seat_per_month\x18\r \x01(\r\x12!\n\x19priority_evaluation_queue\x18\x19 \x01(\x08\x12\x1b\n\x13plagiarism_analysis\x18\x12 \x01(\x08\x12#\n\x1bsubmission_evaluation_limit\x18\x1b \x01(\r\x12\x19\n\x11members_per_space\x18\x02 \x01(\r\x12\x16\n\x0emember_credits\x18\x1c \x01(\x08\x12\x1c\n\x13\x63\x61mpaigns_per_space\x18\xc8\x01 \x01(\r\x12\x17\n\x0e\x65mails_per_day\x18\xc9\x01 \x01(\r\x12\x19\n\x10\x65mails_per_month\x18\xca\x01 \x01(\r\x12\x1d\n\x15scoreboards_per_space\x18\x05 \x01(\r\x12\x19\n\x11\x63ourses_per_space\x18\x0c \x01(\r\x12\x1a\n\x12problems_per_space\x18\x01 \x01(\r\x12\x19\n\x11tests_per_problem\x18\x65 \x01(\r\x12\x1b\n\x13testset_per_problem\x18\x66 \x01(\r\x12\x1d\n\x15statement_per_problem\x18g \x01(\r\x12\x1d\n\x15\x65\x64itorial_per_problem\x18h \x01(\r\x12\x1d\n\x15solutions_per_problem\x18i \x01(\r\x12\"\n\x1a\x63ode_templates_per_problem\x18j \x01(\r\x12\x17\n\x0f\x64\x65\x62ug_assistant\x18x \x01(\x08\x12#\n\x1b\x64\x65\x62ug_hints_daily_per_admin\x18y \x01(\r\x12$\n\x1c\x64\x65\x62ug_hints_daily_per_member\x18z \x01(\r\x12\x1a\n\x12\x63ontests_per_space\x18\x03 \x01(\r\x12!\n\x19\x61\x63tive_contests_per_space\x18\x04 \x01(\r\x12\x1a\n\x12\x63ontests_per_month\x18\x0e \x01(\r\x12\x1c\n\x14problems_per_contest\x18\n \x01(\r\x12 \n\x18participants_per_contest\x18\x0b \x01(\r\x12\x1c\n\x14\x63ontest_upsolve_mode\x18\x10 \x01(\x08\x12\x1c\n\x14max_contest_duration\x18\x11 \x01(\r\x12\x15\n\rteam_contests\x18\x13 \x01(\x08\x12\x1a\n\x12ghost_participants\x18\x14 \x01(\x08\x12\x1f\n\x17unofficial_participants\x18\x15 \x01(\x08\x42\x33Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.quota_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_QUOTA']._serialized_start=49
  _globals['_QUOTA']._serialized_end=1241
# @@protoc_insertion_point(module_scope)
