# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/security_event.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/auth/security_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/auth/security_event.proto\x12\x0b\x65olymp.auth\"\xb7\x03\n\rSecurityEvent\x12\x42\n\x0esession_closed\x18\x01 \x01(\x0b\x32(.eolymp.auth.SecurityEvent.SessionClosedH\x00\x12@\n\rtoken_revoked\x18\x02 \x01(\x0b\x32\'.eolymp.auth.SecurityEvent.TokenRevokedH\x00\x12\x42\n\x0e\x61\x63\x63ount_purged\x18\x03 \x01(\x0b\x32(.eolymp.auth.SecurityEvent.AccountPurgedH\x00\x1a\x44\n\rSessionClosed\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x1a[\n\x0cTokenRevoked\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x12\n\ntoken_type\x18\x03 \x01(\t\x12\x16\n\x0etoken_hash_md5\x18\x04 \x01(\t\x1a\x30\n\rAccountPurged\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\tB\x07\n\x05\x65ventB+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.security_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_SECURITYEVENT']._serialized_start=50
  _globals['_SECURITYEVENT']._serialized_end=489
  _globals['_SECURITYEVENT_SESSIONCLOSED']._serialized_start=269
  _globals['_SECURITYEVENT_SESSIONCLOSED']._serialized_end=337
  _globals['_SECURITYEVENT_TOKENREVOKED']._serialized_start=339
  _globals['_SECURITYEVENT_TOKENREVOKED']._serialized_end=430
  _globals['_SECURITYEVENT_ACCOUNTPURGED']._serialized_start=432
  _globals['_SECURITYEVENT_ACCOUNTPURGED']._serialized_end=480
# @@protoc_insertion_point(module_scope)
