# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/product_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/product_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.commerce import product_pb2 as eolymp_dot_commerce_dot_product__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/commerce/product_service.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/commerce/product.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"?\n\x12\x43reateProductInput\x12)\n\x07product\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Product\")\n\x13\x43reateProductOutput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\x88\x01\n\x12UpdateProductInput\x12\x33\n\x05patch\x18\x03 \x03(\x0e\x32$.eolymp.commerce.Product.Patch.Field\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12)\n\x07product\x18\x02 \x01(\x0b\x32\x18.eolymp.commerce.Product\"\x15\n\x13UpdateProductOutput\"(\n\x12\x44\x65leteProductInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProductOutput\"q\n\x14\x44\x65scribeProductInput\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.commerce.Product.Extra.Field\"B\n\x15\x44\x65scribeProductOutput\x12)\n\x07product\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Product\"\x95\x04\n\x11ListProductsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.commerce.ListProductsInput.Filter\x12\x39\n\x04sort\x18\x32 \x01(\x0e\x32+.eolymp.commerce.ListProductsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x34\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32$.eolymp.commerce.Product.Extra.Field\x1a\xce\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x36\n\x0cout_of_stock\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12.\n\x05price\x18\x04 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"L\n\x12ListProductsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.commerce.Product2\xe7\x06\n\x0eProductService\x12\xa0\x01\n\rCreateProduct\x12#.eolymp.commerce.CreateProductInput\x1a$.eolymp.commerce.CreateProductOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:catalog:write\x82\xd3\xe4\x93\x02\x11\"\x0f/store/products\x12\xad\x01\n\rUpdateProduct\x12#.eolymp.commerce.UpdateProductInput\x1a$.eolymp.commerce.UpdateProductOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:catalog:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/store/products/{product_id}\x12\xad\x01\n\rDeleteProduct\x12#.eolymp.commerce.DeleteProductInput\x1a$.eolymp.commerce.DeleteProductOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommerce:catalog:write\x82\xd3\xe4\x93\x02\x1e*\x1c/store/products/{product_id}\x12\xb2\x01\n\x0f\x44\x65scribeProduct\x12%.eolymp.commerce.DescribeProductInput\x1a&.eolymp.commerce.DescribeProductOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:catalog:read\x82\xd3\xe4\x93\x02\x1e\"\x1c/store/products/{product_id}\x12\x9c\x01\n\x0cListProducts\x12\".eolymp.commerce.ListProductsInput\x1a#.eolymp.commerce.ListProductsOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommerce:catalog:read\x82\xd3\xe4\x93\x02\x11\x12\x0f/store/productsB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.product_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_PRODUCTSERVICE'].methods_by_name['CreateProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['CreateProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026commerce:catalog:write\202\323\344\223\002\021\"\017/store/products'
  _globals['_PRODUCTSERVICE'].methods_by_name['UpdateProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['UpdateProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026commerce:catalog:write\202\323\344\223\002\036\032\034/store/products/{product_id}'
  _globals['_PRODUCTSERVICE'].methods_by_name['DeleteProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['DeleteProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\032\212\343\n\026commerce:catalog:write\202\323\344\223\002\036*\034/store/products/{product_id}'
  _globals['_PRODUCTSERVICE'].methods_by_name['DescribeProduct']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['DescribeProduct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025commerce:catalog:read\202\323\344\223\002\036\"\034/store/products/{product_id}'
  _globals['_PRODUCTSERVICE'].methods_by_name['ListProducts']._loaded_options = None
  _globals['_PRODUCTSERVICE'].methods_by_name['ListProducts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\031\212\343\n\025commerce:catalog:read\202\323\344\223\002\021\022\017/store/products'
  _globals['_CREATEPRODUCTINPUT']._serialized_start=257
  _globals['_CREATEPRODUCTINPUT']._serialized_end=320
  _globals['_CREATEPRODUCTOUTPUT']._serialized_start=322
  _globals['_CREATEPRODUCTOUTPUT']._serialized_end=363
  _globals['_UPDATEPRODUCTINPUT']._serialized_start=366
  _globals['_UPDATEPRODUCTINPUT']._serialized_end=502
  _globals['_UPDATEPRODUCTOUTPUT']._serialized_start=504
  _globals['_UPDATEPRODUCTOUTPUT']._serialized_end=525
  _globals['_DELETEPRODUCTINPUT']._serialized_start=527
  _globals['_DELETEPRODUCTINPUT']._serialized_end=567
  _globals['_DELETEPRODUCTOUTPUT']._serialized_start=569
  _globals['_DELETEPRODUCTOUTPUT']._serialized_end=590
  _globals['_DESCRIBEPRODUCTINPUT']._serialized_start=592
  _globals['_DESCRIBEPRODUCTINPUT']._serialized_end=705
  _globals['_DESCRIBEPRODUCTOUTPUT']._serialized_start=707
  _globals['_DESCRIBEPRODUCTOUTPUT']._serialized_end=773
  _globals['_LISTPRODUCTSINPUT']._serialized_start=776
  _globals['_LISTPRODUCTSINPUT']._serialized_end=1309
  _globals['_LISTPRODUCTSINPUT_FILTER']._serialized_start=1078
  _globals['_LISTPRODUCTSINPUT_FILTER']._serialized_end=1284
  _globals['_LISTPRODUCTSINPUT_SORTABLE']._serialized_start=1286
  _globals['_LISTPRODUCTSINPUT_SORTABLE']._serialized_end=1309
  _globals['_LISTPRODUCTSOUTPUT']._serialized_start=1311
  _globals['_LISTPRODUCTSOUTPUT']._serialized_end=1387
  _globals['_PRODUCTSERVICE']._serialized_start=1390
  _globals['_PRODUCTSERVICE']._serialized_end=2261
# @@protoc_insertion_point(module_scope)
