# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/subscription.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/discussion/subscription.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/discussion/subscription.proto\x12\x11\x65olymp.discussion\"}\n\x0cSubscription\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.eolymp.discussion.Subscription.Type\"9\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05MUTED\x10\x01\x12\x0e\n\nSUBSCRIBED\x10\x02\x12\x0c\n\x08WATCHING\x10\x03\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.subscription_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_SUBSCRIPTION']._serialized_start=59
  _globals['_SUBSCRIPTION']._serialized_end=184
  _globals['_SUBSCRIPTION_TYPE']._serialized_start=127
  _globals['_SUBSCRIPTION_TYPE']._serialized_end=184
# @@protoc_insertion_point(module_scope)
