# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/module_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/course/module_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import module_pb2 as eolymp_dot_course_dot_module__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/course/module_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/course/module.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\":\n\x11\x43reateModuleInput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\'\n\x12\x43reateModuleOutput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\xed\x01\n\x11UpdateModuleInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.course.UpdateModuleInput.Patch\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12%\n\x06module\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Module\"g\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\t\n\x05\x45XTRA\x10\x06\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x05\x12\n\n\x06WEIGHT\x10\x07\"\x14\n\x12UpdateModuleOutput\"&\n\x11\x44\x65leteModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteModuleOutput\"\x8a\x01\n\x13\x44\x65scribeModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x13\n\tmember_id\x18\x02 \x01(\tH\x00\x12\x12\n\x08group_id\x18\x03 \x01(\tH\x00\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.ExtraB\n\n\x08\x61ssignee\"=\n\x14\x44\x65scribeModuleOutput\x12%\n\x06module\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Module\"\x9e\x04\n\x10ListModulesInput\x12\x13\n\tmember_id\x18\x05 \x01(\tH\x00\x12\x12\n\x08group_id\x18\x06 \x01(\tH\x00\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListModulesInput.Filter\x12\x32\n\x04sort\x18\x32 \x01(\x0e\x32$.eolymp.course.ListModulesInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.course.Module.Extra\x1a\xcd\x01\n\x06\x46ilter\x12/\n\x05\x64raft\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x05\x65xtra\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06graded\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x06weight\x18\x05 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\x42\n\n\x08\x61ssignee\"H\n\x11ListModulesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.course.Module\"%\n\x10StartModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x13\n\x11StartModuleOutput\"e\n\x10GradeModuleInput\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0f\n\x05grade\x18\x03 \x01(\rH\x00\x12\x11\n\x07\x65xcused\x18\x04 \x01(\x08H\x00\x42\x07\n\x05value\"\x13\n\x11GradeModuleOutput2\xce\x08\n\rModuleService\x12\x8f\x01\n\x0c\x43reateModule\x12 .eolymp.course.CreateModuleInput\x1a!.eolymp.course.CreateModuleOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\n\x1a\x08/modules\x12\x9b\x01\n\x0cUpdateModule\x12 .eolymp.course.UpdateModuleInput\x1a!.eolymp.course.UpdateModuleOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x16\x1a\x14/modules/{module_id}\x12\x9b\x01\n\x0c\x44\x65leteModule\x12 .eolymp.course.DeleteModuleInput\x1a!.eolymp.course.DeleteModuleOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\x82\xd3\xe4\x93\x02\x16*\x14/modules/{module_id}\x12\xa0\x01\n\x0e\x44\x65scribeModule\x12\".eolymp.course.DescribeModuleInput\x1a#.eolymp.course.DescribeModuleOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x16\x12\x14/modules/{module_id}\x12\x8b\x01\n\x0bListModules\x12\x1f.eolymp.course.ListModulesInput\x1a .eolymp.course.ListModulesOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\n\x12\x08/modules\x12\x9d\x01\n\x0bStartModule\x12\x1f.eolymp.course.StartModuleInput\x1a .eolymp.course.StartModuleOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x1c\"\x1a/modules/{module_id}/start\x12\x9d\x01\n\x0bGradeModule\x12\x1f.eolymp.course.GradeModuleInput\x1a .eolymp.course.GradeModuleOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x1c\"\x1a/modules/{module_id}/gradeB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_MODULESERVICE'].methods_by_name['CreateModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['CreateModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\n\032\010/modules'
  _globals['_MODULESERVICE'].methods_by_name['UpdateModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['UpdateModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\026\032\024/modules/{module_id}'
  _globals['_MODULESERVICE'].methods_by_name['DeleteModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['DeleteModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023course:course:write\202\323\344\223\002\026*\024/modules/{module_id}'
  _globals['_MODULESERVICE'].methods_by_name['DescribeModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['DescribeModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\026\022\024/modules/{module_id}'
  _globals['_MODULESERVICE'].methods_by_name['ListModules']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['ListModules']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\n\022\010/modules'
  _globals['_MODULESERVICE'].methods_by_name['StartModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['StartModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\034\"\032/modules/{module_id}/start'
  _globals['_MODULESERVICE'].methods_by_name['GradeModule']._loaded_options = None
  _globals['_MODULESERVICE'].methods_by_name['GradeModule']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\034\"\032/modules/{module_id}/grade'
  _globals['_CREATEMODULEINPUT']._serialized_start=249
  _globals['_CREATEMODULEINPUT']._serialized_end=307
  _globals['_CREATEMODULEOUTPUT']._serialized_start=309
  _globals['_CREATEMODULEOUTPUT']._serialized_end=348
  _globals['_UPDATEMODULEINPUT']._serialized_start=351
  _globals['_UPDATEMODULEINPUT']._serialized_end=588
  _globals['_UPDATEMODULEINPUT_PATCH']._serialized_start=485
  _globals['_UPDATEMODULEINPUT_PATCH']._serialized_end=588
  _globals['_UPDATEMODULEOUTPUT']._serialized_start=590
  _globals['_UPDATEMODULEOUTPUT']._serialized_end=610
  _globals['_DELETEMODULEINPUT']._serialized_start=612
  _globals['_DELETEMODULEINPUT']._serialized_end=650
  _globals['_DELETEMODULEOUTPUT']._serialized_start=652
  _globals['_DELETEMODULEOUTPUT']._serialized_end=672
  _globals['_DESCRIBEMODULEINPUT']._serialized_start=675
  _globals['_DESCRIBEMODULEINPUT']._serialized_end=813
  _globals['_DESCRIBEMODULEOUTPUT']._serialized_start=815
  _globals['_DESCRIBEMODULEOUTPUT']._serialized_end=876
  _globals['_LISTMODULESINPUT']._serialized_start=879
  _globals['_LISTMODULESINPUT']._serialized_end=1421
  _globals['_LISTMODULESINPUT_FILTER']._serialized_start=1185
  _globals['_LISTMODULESINPUT_FILTER']._serialized_end=1390
  _globals['_LISTMODULESINPUT_SORT']._serialized_start=1392
  _globals['_LISTMODULESINPUT_SORT']._serialized_end=1409
  _globals['_LISTMODULESOUTPUT']._serialized_start=1423
  _globals['_LISTMODULESOUTPUT']._serialized_end=1495
  _globals['_STARTMODULEINPUT']._serialized_start=1497
  _globals['_STARTMODULEINPUT']._serialized_end=1534
  _globals['_STARTMODULEOUTPUT']._serialized_start=1536
  _globals['_STARTMODULEOUTPUT']._serialized_end=1555
  _globals['_GRADEMODULEINPUT']._serialized_start=1557
  _globals['_GRADEMODULEINPUT']._serialized_end=1658
  _globals['_GRADEMODULEOUTPUT']._serialized_start=1660
  _globals['_GRADEMODULEOUTPUT']._serialized_end=1679
  _globals['_MODULESERVICE']._serialized_start=1682
  _globals['_MODULESERVICE']._serialized_end=2784
# @@protoc_insertion_point(module_scope)
