# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/worker/worker_job.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/worker/worker_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/worker/worker_job.proto\x12\reolymp.worker\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x05\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12)\n\x06status\x18\x1e \x01(\x0e\x32\x19.eolymp.worker.Job.Status\x12\x10\n\x08progress\x18\x14 \x01(\r\x12\r\n\x05total\x18\x15 \x01(\r\x12.\n\x06inputs\x18\x04 \x03(\x0b\x32\x1e.eolymp.worker.Job.InputsEntry\x12\x30\n\x07outputs\x18\x1f \x03(\x0b\x32\x1f.eolymp.worker.Job.OutputsEntry\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bprogress_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63omplete_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08logs_url\x18\x64 \x01(\t\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cOutputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"v\n\x05Patch\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\r\n\tPATCH_ALL\x10\x01\x12\x12\n\x0ePATCH_PROGRESS\x10\x02\x12\x11\n\rPATCH_OUTPUTS\x10\x03\x12\x12\n\x0ePATCH_LOGS_URL\x10\x04\x12\x10\n\x0cPATCH_STATUS\x10\x05\x42/Z-github.com/eolymp/go-sdk/eolymp/worker;workerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.worker.worker_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/worker;worker'
  _globals['_JOB_INPUTSENTRY']._loaded_options = None
  _globals['_JOB_INPUTSENTRY']._serialized_options = b'8\001'
  _globals['_JOB_OUTPUTSENTRY']._loaded_options = None
  _globals['_JOB_OUTPUTSENTRY']._serialized_options = b'8\001'
  _globals['_JOB']._serialized_start=83
  _globals['_JOB']._serialized_end=808
  _globals['_JOB_INPUTSENTRY']._serialized_start=521
  _globals['_JOB_INPUTSENTRY']._serialized_end=566
  _globals['_JOB_OUTPUTSENTRY']._serialized_start=568
  _globals['_JOB_OUTPUTSENTRY']._serialized_end=614
  _globals['_JOB_STATUS']._serialized_start=616
  _globals['_JOB_STATUS']._serialized_end=688
  _globals['_JOB_PATCH']._serialized_start=690
  _globals['_JOB_PATCH']._serialized_end=808
# @@protoc_insertion_point(module_scope)
